@@ -1,4 +1,4 @@
-#   include	"config.h"
+#   include	"tedConfig.h"
 
 #   include	"docBuf.h"
 #   include	<stdio.h>
@@ -8,22 +8,57 @@
 #   define	LIST_FIRST_LINE		0
 #   define	LIST_LINES		1
 #   define	LIST_LINE_PARTICULES	0
+#   define	CHECK_GEOMETRY		0
 
-static void docCheckChild(	const BufferItem *	parent,
+static int docCheckGroupLeft(	const BufferItem *	bi )
+    {
+    int		rval= 0;
+
+    int		prev= 0;
+    int		here;
+
+    if  ( bi->biParent && bi->biNumberInParent > 0 )
+	{
+	prev= bi->biParent->biChildren[bi->biNumberInParent-1]->
+						biLeftParagraphs;
+	}
+
+    here= bi->biLeftParagraphs;
+
+    if  ( here- prev !=
+	    bi->biChildren[bi->biChildCount- 1]->biLeftParagraphs )
+	{
+	SLDEB(docLevelStr(bi->biLevel),here- prev);
+	LDEB(bi->biChildren[bi->biChildCount- 1]->biLeftParagraphs);
+	rval= -1;
+	}
+
+    return rval;
+    }
+
+static int docCheckChild(	const BufferItem *	parent,
 				const BufferItem *	child,
 				int			i,
 				const LayoutPosition *	lpTop,
 				LayoutPosition *	lpBelow )
     {
-    if  ( child->biTopPosition.lpPage != lpTop->lpPage			||
-	  child->biTopPosition.lpPageYTwips != lpTop->lpPageYTwips	)
+    int		rval= 0;
+
+#   if  CHECK_GEOMETRY
+    if  ( lpTop )
 	{
-	appDebug( "############## %s %d in %s:\n",
-				    docLevelStr(child->biLevel), i,
-				    docLevelStr(parent->biLevel) );
-	LLDEB(child->biTopPosition.lpPage,lpTop->lpPage);
-	LLDEB(child->biTopPosition.lpPageYTwips,lpTop->lpPageYTwips);
+	if  ( child->biTopPosition.lpPage != lpTop->lpPage		||
+	      child->biTopPosition.lpPageYTwips != lpTop->lpPageYTwips	)
+	    {
+	    appDebug( "############## %s %d in %s:\n",
+					docLevelStr(child->biLevel), i,
+					docLevelStr(parent->biLevel) );
+	    LLDEB(child->biTopPosition.lpPage,lpTop->lpPage);
+	    LLDEB(child->biTopPosition.lpPageYTwips,lpTop->lpPageYTwips);
+	    rval= -1;
+	    }
 	}
+#   endif
 
     if  ( child->biParent != parent )
 	{
@@ -31,6 +66,7 @@ static void docCheckChild(	const BufferItem *	parent,
 				    docLevelStr(child->biLevel), i,
 				    docLevelStr(parent->biLevel) );
 	XXDEB(child->biParent,parent);
+	rval= -1;
 	}
 
     if  ( child->biNumberInParent != i )
@@ -39,6 +75,7 @@ static void docCheckChild(	const BufferItem *	parent,
 				    docLevelStr(child->biLevel), i,
 				    docLevelStr(parent->biLevel) );
 	LLDEB(child->biNumberInParent,i);
+	rval= -1;
 	}
 
     if  ( child->biLevel != parent->biLevel+ 1 )
@@ -47,9 +84,78 @@ static void docCheckChild(	const BufferItem *	parent,
 				    docLevelStr(child->biLevel), i,
 				    docLevelStr(parent->biLevel) );
 	LLDEB(child->biLevel,parent->biLevel);
+	rval= -1;
 	}
 
-    *lpBelow= child->biBelowPosition;
+    if  ( child->biInExternalItem != parent->biInExternalItem )
+	{
+	appDebug( "############## %s %d in %s:\n",
+				    docLevelStr(child->biLevel), i,
+				    docLevelStr(parent->biLevel) );
+	LLDEB(child->biInExternalItem,parent->biInExternalItem);
+	rval= -1;
+	}
+
+    if  ( lpBelow )
+	{ *lpBelow= child->biBelowPosition;	}
+
+    return rval;
+    }
+
+int docCheckItem(		const BufferItem *	bi )
+    {
+    int			i;
+    int			rval= 0;
+
+    if  ( bi->biLevel == DOClevPARA )
+	{
+	if  ( bi->biLeftParagraphs != bi->biNumberInParent+ 1 )
+	    {
+	    appDebug( "############## %s:\n",
+				    docLevelStr(bi->biLevel) );
+	    LLDEB(bi->biLeftParagraphs,bi->biNumberInParent+1);
+	    }
+	}
+
+    if  ( bi->biChildCount > 0 )
+	{
+	if  ( docCheckGroupLeft( bi ) )
+	    { rval= -1;	}
+
+	if  ( ! bi->biParent )
+	    {
+	    DocumentPosition	dp;
+	    docInitDocumentPosition( &dp );
+
+	    if  ( ! docFirstPosition( &dp, (BufferItem *)bi ) )
+		{
+		const BufferItem *	paraBi= dp.dpBi;
+		int			n= 1;
+
+		for (;;)
+		    {
+		    if  ( docNumberOfParagraph( paraBi ) != n )
+			{ LLDEB(docNumberOfParagraph(paraBi),n); rval= -1; }
+
+		    paraBi= docNextParagraph( (BufferItem *)paraBi );
+		    if  ( ! paraBi )
+			{ break;	}
+		    n++;
+		    }
+		}
+	    }
+	}
+
+    for ( i= 0; i < bi->biChildCount; i++ )
+	{
+	if  ( docCheckChild( bi, bi->biChildren[i], i,
+				(LayoutPosition *)0, (LayoutPosition *)0 ) )
+	    { rval= -1;	}
+	if  ( docCheckItem( bi->biChildren[i] ) )
+	    { rval= -1;	}
+	}
+
+    return rval;
     }
 
 static void docListChildren(	int			indent,
@@ -68,6 +174,10 @@ static void docListChildren(	int			indent,
 	docListItem( indent+ 4, bi->biChildren[i] );
 	}
 
+    if  ( bi->biChildCount > 0 )
+	{ docCheckGroupLeft( bi );	}
+
+#   if CHECK_GEOMETRY
     if  ( bi->biBelowPosition.lpPage != lp.lpPage		||
 	  bi->biBelowPosition.lpPageYTwips != lp.lpPageYTwips	)
 	{
@@ -76,6 +186,7 @@ static void docListChildren(	int			indent,
 	LLDEB(bi->biBelowPosition.lpPage,lp.lpPage);
 	LLDEB(bi->biBelowPosition.lpPageYTwips,lp.lpPageYTwips);
 	}
+#   endif
 
     }
 
@@ -94,10 +205,11 @@ void docListItem(	int			indent,
     TextLine *		tl;
 #   endif
 
-    appDebug( "%*sITEM %4d 0x%08lx: %s\n",
+    appDebug( "%*sITEM %4d 0x%08lx: %s LEFT= %d\n",
 			    indent, "", bi->biNumberInParent,
 			    (unsigned long)bi,
-			    docLevelStr( bi->biLevel ) );
+			    docLevelStr( bi->biLevel ),
+			    bi->biLeftParagraphs );
     switch( bi->biLevel )
 	{
 	case DOClevDOC:
@@ -120,7 +232,8 @@ void docListItem(	int			indent,
 	    break;
 
 	case DOClevPARA:
-	    appDebug( "%*s{ %4d particules, %4d lines\n", indent+ 4, "",
+	    appDebug( "%*s{ NR= %d %d particules, %d lines\n", indent+ 4, "",
+						docNumberOfParagraph( bi ),
 						bi->biParaParticuleCount,
 						bi->biParaLineCount );
 
@@ -162,6 +275,7 @@ const char * docKindStr( int kind )
 	case DOCkindOBJECT:	return "OBJ";
 	case DOCkindFIELDSTART:	return "FLS";
 	case DOCkindFIELDEND:	return "FLE";
+	case DOCkindNOTE:	return "NOT";
 	case DOCkindXE:		return "XE ";
 	case DOCkindTC:		return "TC ";
 	case DOCkindLINEBREAK:	return "LIN";
@@ -192,11 +306,11 @@ const char * docLevelStr( int level )
 	}
     }
 
-const char * docExternalKindStr( int inHeaderFooter )
+const char * docExternalKindStr( int inExternalItem )
     {
     static char	scratch[12];
 
-    switch( inHeaderFooter )
+    switch( inExternalItem )
 	{
 	case DOCinBODY:			return "BODY";
 
@@ -210,8 +324,19 @@ const char * docExternalKindStr( int inHeaderFooter )
 	case DOCinLEFT_FOOTER:		return "LEFT_FOOTER";
 	case DOCinRIGHT_FOOTER:		return "RIGHT_FOOTER";
 
+	case DOCinFOOTNOTE:		return "FOOTNOTE";
+	case DOCinENDNOTE:		return "ENDNOTE";
+
+	case DOCinFTNSEP:		return "FTNSEP";
+	case DOCinFTNSEPC:		return "FTNSEPC";
+	case DOCinFTNCN:		return "FTNCN";
+
+	case DOCinAFTNSEP:		return "AFTNSEP";
+	case DOCinAFTNSEPC:		return "AFTNSEPC";
+	case DOCinAFTNCN:		return "AFTNCN";
+
 	default:
-	    sprintf( scratch, "%d", inHeaderFooter );
+	    sprintf( scratch, "%d", inExternalItem );
 	    return scratch;
 	}
     }
@@ -256,7 +381,8 @@ void docListParticule(	int			indent,
 			const BufferItem *	bi,
 			const TextParticule *	tp )
     {
-    appDebug( "%*s%s %3d: [%4d..%4d] [%3d..%3d] %s <%s> ", indent, "", label, n,
+    appDebug( "%*s%s %3d: [S %4d..%4d] [X %3d..%3d] %s <%s> ",
+		    indent, "", label, n,
 		    tp->tpStroff, tp->tpStroff+ tp->tpStrlen,
 		    tp->tpX0, tp->tpX0+ tp->tpPixelsWide,
 		    docKindStr( tp->tpKind ),
