@@ -4,7 +4,7 @@
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"tedConfig.h"
 
 #   include	<stdlib.h>
 #   include	<string.h>
@@ -15,85 +15,9 @@
 #   include	<appUnit.h>
 
 #   include	"docBuf.h"
+#   include	"docEdit.h"
 
-/*
-# define DEB_PARTICULES
-*/
-
-/************************************************************************/
-/*									*/
-/*  Redivide a piece of a paragraph in particules.			*/
-/*									*/
-/************************************************************************/
-
-int docRedivideStringInParticules(	BufferItem *	bi,
-					int		strOff,
-					int		strLen,
-					int		part,
-					int		partsFree,
-					TextAttribute	ta )
-    {
-    int			bytesDone= 0;
-    int			partsDone= 0;
-
-    TextParticule *	tp= bi->biParaParticules+ part;
-
-    while( bytesDone < strLen )
-	{
-	int	len= 0;
-#	ifdef DEB_PARTICULES
-	char *	label= "???";
-#	endif
-
-	while( bytesDone+ len < strLen			&&
-	       bi->biParaString[strOff+ len] != ' '	)
-	    { len++;	}
-	while( bytesDone+ len < strLen			&&
-	       bi->biParaString[strOff+ len] == ' '	)
-	    { len++;	}
-
-	if  ( partsDone < partsFree )
-	    {
-	    tp->tpStroff= strOff;
-	    tp->tpStrlen= len;
-	    tp->tpKind= DOCkindTEXT;
-	    tp->tpTextAttribute= ta;
-
-	    tp->tpPhysicalFont= -1;
-	    tp->tpX0= -1;
-	    tp->tpPixelsWide= 0;
-
-#	    ifdef DEB_PARTICULES
-	    label= "NW.";
-#	    endif
-	    }
-	else{
-	    tp= docInsertTextParticule( bi, part,
-					    strOff, len, DOCkindTEXT, ta );
-	    if  ( ! tp )
-		{ XDEB(tp); return -1;	}
-#	    ifdef DEB_PARTICULES
-	    label= "NW+";
-#	    endif
-	    }
-
-#	ifdef DEB_PARTICULES
-	appDebug( "%s %3d: [%4d..%4d] %s <%s> \"%.*s\" len= %d\n", label, part,
-		    tp->tpStroff,
-		    tp->tpStroff+ tp->tpStrlen,
-		    docKindStr( tp->tpKind ),
-		    docAttributeStr( tp->tpTextAttribute ),
-		    (int)tp->tpStrlen,
-		    bi->biParaString+ tp->tpStroff,
-		    tp->tpStrlen );
-#	endif
-
-	strOff += len; bytesDone += len;
-	partsDone++; part++, tp++;
-	}
-
-    return partsDone;
-    }
+#   define	DEB_PARTICULES		0
 
 /************************************************************************/
 /*									*/
@@ -159,7 +83,8 @@ static int docCleanupFields(	BufferDocument *	bd,
 
 		if  ( i < fieldCount )
 		    {
-		    docCleanField( bd, dfFrom ); docInitField( dfFrom );
+		    docCleanField( dfFrom );
+		    docInitField( dfFrom );
 		    fieldParticules[from].tpKind= DOCkindUNKNOWN; /* a */
 		    fieldParticules[i].tpKind= DOCkindUNKNOWN;
 		    }
@@ -180,7 +105,8 @@ static int docCleanupFields(	BufferDocument *	bd,
 	    case DOCkindTC:
 		dfFrom= bd->bdFieldList.dflFields+
 					fieldParticules[from].tpObjectNumber;
-		docCleanField( bd, dfFrom ); docInitField( dfFrom );
+		docCleanField( dfFrom );
+		docInitField( dfFrom );
 		fieldParticules[from].tpKind= DOCkindUNKNOWN; /* a */
 		continue;
 
@@ -256,7 +182,7 @@ static int docReinsertFieldParticule(	BufferDocument *	bd,
 		tpField->tpStrlen, tpField->tpKind, tpField->tpTextAttribute );
 	}
 
-#   ifdef DEB_PARTICULES
+#   if DEB_PARTICULES
     appDebug( "NFL %3d: [%4d..%4d] %s <%s> \"%.*s\" len= %d\n", part,
 		    tpTo->tpStroff,
 		    tpTo->tpStroff+ tpTo->tpStrlen,
@@ -398,6 +324,11 @@ static void docFindSubstitutionEnd(	int *			pPartEnd,
 	       tpEnd->tpStroff+ tpEnd->tpStrlen == stroffEnd		)
 	    { tpEnd++; partEnd++;	}
 
+	while( partEnd < bi->biParaParticuleCount- 1			&&
+	       tpEnd[1].tpKind == DOCkindNOTE				&&
+	       tpEnd->tpStroff+ tpEnd->tpStrlen == stroffEnd		)
+	    { tpEnd++; partEnd++;	}
+
 	*pPartEnd= partEnd; *pTpEnd= tpEnd; return;
 	}
 
@@ -417,18 +348,16 @@ static void docFindSubstitutionEnd(	int *			pPartEnd,
     *pPartEnd= partEnd; *pTpEnd= tpEnd; return;
     }
 
-int docParaReplaceText(	BufferDocument *	bd,
-			BufferItem *		bi,
-			int			partBegin,
-			unsigned int		stroffBegin,
-			int *			pPartShift,
-			int *			pStroffShift,
-			unsigned int		stroffEnd,
-			const unsigned char *	addedString,
-			unsigned int		addedStrlen,
-			TextAttribute		addedAttr,
-			void *			voidadd,
-			DOC_CLOSE_OBJECT	closeObject )
+int docParaReplaceText(		EditOperation *		eo,
+				BufferItem *		bi,
+				int			partBegin,
+				unsigned int		stroffBegin,
+				int *			pPartShift,
+				int *			pStroffShift,
+				unsigned int		stroffEnd,
+				const unsigned char *	addedString,
+				unsigned int		addedStrlen,
+				TextAttribute		addedAttr )
     {
     int				stroffShift;
     int				partShift;
@@ -511,7 +440,7 @@ int docParaReplaceText(	BufferDocument *	bd,
 	{
 	tpBegin->tpStrlen= newBegin- tpBegin->tpStroff;
 
-#	ifdef DEB_PARTICULES
+#	if DEB_PARTICULES
 	appDebug( "<<= %3d: [%4d..%4d] %s <%s> \"%.*s\"\n", partBegin,
 				tpBegin->tpStroff,
 				tpBegin->tpStroff+ tpBegin->tpStrlen,
@@ -543,7 +472,7 @@ int docParaReplaceText(	BufferDocument *	bd,
 	    tpEnd->tpStrlen= stroffEndEnd- newEnd;
 	    }
 
-#	ifdef DEB_PARTICULES
+#	if DEB_PARTICULES
 	appDebug( "=>> %3d: [%4d..%4d] %s <%s> \"%.*s\"\n", partEnd,
 				tpEnd->tpStroff,
 				tpEnd->tpStroff+ tpEnd->tpStrlen,
@@ -570,7 +499,7 @@ int docParaReplaceText(	BufferDocument *	bd,
     tp= tpBegin;
     for ( part= partBegin; part <= partEnd; tp++, part++ )
 	{
-#	ifdef DEB_PARTICULES
+#	if DEB_PARTICULES
 	appDebug( "OLD %3d: [%4d..%4d] %s <%s> \"%.*s\"\n", part,
 		    tp->tpStroff,
 		    tp->tpStroff+ tp->tpStrlen,
@@ -580,7 +509,8 @@ int docParaReplaceText(	BufferDocument *	bd,
 		    bi->biParaString+ tp->tpStroff );
 #	endif
 
-	(*closeObject)( bd, bi, tp, voidadd );
+	if  ( eo->eoCloseObject )
+	    { (*eo->eoCloseObject)( eo->eoBd, bi, tp, eo->eoVoidadd );	}
 	docCleanParticuleObject( bi, tp );
 
 	if  ( tp->tpKind == DOCkindFIELDSTART	||
@@ -589,6 +519,14 @@ int docParaReplaceText(	BufferDocument *	bd,
 	      tp->tpKind == DOCkindTC		)
 	    { fieldParticules[fieldCount++]= *tp;	}
 
+	if  ( tp->tpKind == DOCkindNOTE )
+	    {
+	    if  ( docDeleteNoteOfParticule( eo->eoBd, bi, tp ) )
+		{ LDEB(tp->tpStroff);	}
+
+	    eo->eoNotesDeleted++;
+	    }
+
 	partShift--; oldCount++;
 	}
 
@@ -599,7 +537,10 @@ int docParaReplaceText(	BufferDocument *	bd,
 
     /*  13  */
     if  ( fieldCount > 0 )
-	{ fieldCount= docCleanupFields( bd, bi, fieldParticules, fieldCount ); }
+	{
+	fieldCount=
+	    docCleanupFields( eo->eoBd, bi, fieldParticules, fieldCount );
+	}
     if  ( fieldCount < 0 )
 	{ LDEB(fieldCount); return -1;	}
 
@@ -618,11 +559,11 @@ int docParaReplaceText(	BufferDocument *	bd,
 
 	if  ( newCount < oldCount )
 	    {
-	    res= docReinsertFieldParticule( bd, bi, newBegin, part,
+	    res= docReinsertFieldParticule( eo->eoBd, bi, newBegin, part,
 							tpField, tp );
 	    }
 	else{
-	    res= docReinsertFieldParticule( bd, bi, newBegin, part,
+	    res= docReinsertFieldParticule( eo->eoBd, bi, newBegin, part,
 					    tpField, (TextParticule *)0 );
 	    }
 
@@ -657,11 +598,11 @@ int docParaReplaceText(	BufferDocument *	bd,
 
 	if  ( newCount < oldCount )
 	    {
-	    res= docReinsertFieldParticule( bd, bi, newEnd, part,
+	    res= docReinsertFieldParticule( eo->eoBd, bi, newEnd, part,
 					tpField, bi->biParaParticules+ part );
 	    }
 	else{
-	    res= docReinsertFieldParticule( bd, bi, newEnd, part,
+	    res= docReinsertFieldParticule( eo->eoBd, bi, newEnd, part,
 					tpField, (TextParticule *)0 );
 	    }
 
@@ -692,14 +633,11 @@ int docParaReplaceText(	BufferDocument *	bd,
 	}
 
     /*  21  */
-    tp= bi->biParaParticules+ part;
-    while( part < bi->biParaParticuleCount )
-	{
-	tp->tpStroff += stroffShift;
-	part++; tp++;
-	}
+    if  ( docShiftParticuleOffsets( eo->eoBd, bi,
+			    part, bi->biParaParticuleCount, stroffShift ) )
+	{ LDEB(stroffShift);	}
 
-#   ifdef DEB_PARTICULES
+#   if DEB_PARTICULES
     appDebug( "\n" );
 
     part= 0; tp= bi->biParaParticules;
@@ -736,16 +674,14 @@ int docParaReplaceText(	BufferDocument *	bd,
 /*									*/
 /************************************************************************/
 
-static int docParaAppend(	BufferDocument *	bdTo,
+static int docParaAppend(	EditOperation *		eo,
 				const BufferDocument *	bdFrom,
 				int *			fieldMap,
 				unsigned int *		pFieldUpd,
 				BufferItem *		biTo,
 				BufferItem *		biFrom,
 				int			part,
-				unsigned int		stroffFrom,
-				void *			voidadd,
-				DOC_CLOSE_OBJECT	closeObject )
+				unsigned int		stroffFrom )
     {
     TextParticule *	tpFrom= biFrom->biParaParticules+ part;
     TextParticule *	newTp;
@@ -780,14 +716,13 @@ static int docParaAppend(	BufferDocument *	bdTo,
 	    {
 	    int		ignored;
 
-	    if  ( docParaReplaceText( bdTo, biTo, biTo->biParaParticuleCount- 1,
+	    if  ( docParaReplaceText( eo, biTo, biTo->biParaParticuleCount- 1,
 				biTo->biParaStrlen,
 				&partShift, &ignored,
 				biTo->biParaStrlen,
 				biFrom->biParaString+ stroffFrom,
 				tpFrom->tpStroff+ tpFrom->tpStrlen- stroffFrom,
-				tpFrom->tpTextAttribute,
-				voidadd, closeObject ) )
+				tpFrom->tpTextAttribute ) )
 		{ LDEB(tpFrom->tpStrlen); return -1;	}
 
 	    stroffFrom= tpFrom->tpStroff+ tpFrom->tpStrlen;
@@ -813,7 +748,7 @@ static int docParaAppend(	BufferDocument *	bdTo,
 	if  ( ! newTp )
 	    { LDEB(biTo->biParaParticuleCount); return -1;	}
 
-	if  ( docCopyParticuleData( bdTo, bdFrom, fieldMap, pFieldUpd,
+	if  ( docCopyParticuleData( eo->eoBd, bdFrom, fieldMap, pFieldUpd,
 						biTo, biFrom, newTp, tpFrom ) )
 	    { LDEB(part); return -1;	}
 
@@ -834,6 +769,73 @@ static int docParaAppend(	BufferDocument *	bdTo,
     return 0;
     }
 
+/************************************************************************/
+/*									*/
+/*  The current selection consisted of several paragraphs. An edit	*/
+/*  operation was executed on the first one.. The rest is to be		*/
+/*  deleted.								*/
+/*									*/
+/************************************************************************/
+
+int docRemoveSelectionTail(		EditOperation *		eo,
+					const DocumentSelection *	ds )
+    {
+    BufferItem *	nextBi;
+    int			paraShift= 0;
+    int			sectShift= 0;
+
+    nextBi= docNextParagraph( ds->dsBegin.dpBi );
+    if  ( ! nextBi )
+	{ XDEB(nextBi); return -1;	}
+
+    for (;;)
+	{
+	BufferItem *	parent= nextBi->biParent;
+	BufferItem *	pp;
+
+	docEditDeleteItems( eo, parent, nextBi->biNumberInParent, 1 );
+	paraShift++;
+
+	if  ( nextBi == ds->dsEnd.dpBi )
+	    {
+	    while( parent && parent->biChildCount == 0 )
+		{
+		pp= parent->biParent;
+		docDeleteItem( eo->eoBd, parent );
+		parent= pp;
+		}
+
+	    break;
+	    }
+
+	nextBi= docNextParagraph( ds->dsBegin.dpBi );
+	if  ( ! nextBi )
+	    { XDEB(nextBi); return -1;	}
+
+	while( parent && parent->biChildCount == 0 )
+	    {
+	    pp= parent->biParent;
+	    docDeleteItem( eo->eoBd, parent );
+	    parent= pp;
+	    }
+	}
+
+    if  ( paraShift > 0 )
+	{
+	int	paraNr= docNumberOfParagraph( ds->dsBegin.dpBi );
+
+	if  ( ds->dsBegin.dpBi->biInExternalItem == DOCinBODY )
+	    {
+	    docShiftNoteReferences( eo->eoBd, paraNr+ 1, 0,
+						-sectShift, -paraShift, 0 );
+	    }
+
+	docEditShiftReformatRangeParaNr( eo, paraNr+ 1, -paraShift );
+	}
+
+    return 0;
+    }
+
 /************************************************************************/
 /*									*/
 /*  Replace a selection with a piece of text.				*/
@@ -846,86 +848,53 @@ static int docParaAppend(	BufferDocument *	bdTo,
 /*									*/
 /************************************************************************/
 
-int docReplaceSelection(	BufferDocument *	bd,
-				const BufferSelection *	bs,
+int docReplaceSelection(	EditOperation *		eo,
+				const DocumentSelection *	ds,
 				int *			pPartShift,
 				int *			pStroffShift,
 				const unsigned char *	addedString,
 				int			addedStrlen,
-				TextAttribute		addedAttribute,
-				void *			voidadd,
-				DOC_CLOSE_OBJECT	closeObject )
+				TextAttribute		addedAttribute )
     {
     /*  a  */
-    if  ( bs->bsBegin.bpBi != bs->bsEnd.bpBi )
+    if  ( ds->dsBegin.dpBi != ds->dsEnd.dpBi )
 	{
-	BufferItem *	nextBi;
-
 	/*  b  */
-	if  ( docParaReplaceText( bd, bs->bsBegin.bpBi,
-		    bs->bsBegin.bpParticule, bs->bsBegin.bpStroff,
+	if  ( docParaReplaceText( eo, ds->dsBegin.dpBi,
+		    ds->dsBegin.dpParticule, ds->dsBegin.dpStroff,
 		    pPartShift, pStroffShift,
-		    bs->bsBegin.bpBi->biParaStrlen,
-		    addedString, addedStrlen, addedAttribute,
-		    voidadd, closeObject ) )
+		    ds->dsBegin.dpBi->biParaStrlen,
+		    addedString, addedStrlen, addedAttribute ) )
 	    { LDEB(addedStrlen); return -1;	}
 
 	/*  c  */
-	if  ( bs->bsEnd.bpStroff < bs->bsEnd.bpBi->biParaStrlen )
+	if  ( ds->dsEnd.dpStroff < ds->dsEnd.dpBi->biParaStrlen )
 	    {
 	    int *		fieldMap;
 	    unsigned int	fieldUpd= FIELDdoNOTHING;
 
-	    fieldMap= docAllocateFieldMap( bd );
+	    fieldMap= docAllocateFieldMap( eo->eoBd );
 	    if  ( ! fieldMap )
 		{ XDEB(fieldMap); return -1;	}
 
-	    if  ( docParaAppend( bd, bd, fieldMap, &fieldUpd,
-				    bs->bsBegin.bpBi, bs->bsEnd.bpBi,
-				    bs->bsEnd.bpParticule, bs->bsEnd.bpStroff,
-				    voidadd, closeObject ) )
+	    if  ( docParaAppend( eo, eo->eoBd, fieldMap, &fieldUpd,
+				ds->dsBegin.dpBi, ds->dsEnd.dpBi,
+				ds->dsEnd.dpParticule, ds->dsEnd.dpStroff ) )
 		{ LDEB(addedStrlen); free( fieldMap ); return -1;	}
 
 	    free( fieldMap );
 	    }
 
-	nextBi= docNextParagraph( bs->bsBegin.bpBi );
-	if  ( ! nextBi )
-	    { XDEB(nextBi); return -1;	}
-
-	/*  d  */
-	for (;;)
-	    {
-	    BufferItem *	para= nextBi->biParent;
-	    BufferItem *	pp;
-
-	    docCloseItemObjects( bd, nextBi, voidadd, closeObject );
-	    docDeleteItem( bd, nextBi );
-
-	    if  ( nextBi == bs->bsEnd.bpBi )
-		{
-		while( para && para->biChildCount == 0 )
-		    { pp= para->biParent; docDeleteItem( bd, para ); para= pp; }
-
-		break;
-		}
-
-	    nextBi= docNextParagraph( bs->bsBegin.bpBi );
-	    if  ( ! nextBi )
-		{ XDEB(nextBi); return -1;	}
-
-	    while( para && para->biChildCount == 0 )
-		{ pp= para->biParent; docDeleteItem( bd, para ); para= pp; }
-	    }
+	if  ( docRemoveSelectionTail( eo, ds ) )
+	    { LDEB(1); return -1;	}
 	}
     else{
 	/*  e  */
-	if  ( docParaReplaceText( bd, bs->bsBegin.bpBi, bs->bsBegin.bpParticule,
-			    bs->bsBegin.bpStroff,
+	if  ( docParaReplaceText( eo, ds->dsBegin.dpBi, ds->dsBegin.dpParticule,
+			    ds->dsBegin.dpStroff,
 			    pPartShift, pStroffShift,
-			    bs->bsEnd.bpStroff,
-			    addedString, addedStrlen, addedAttribute,
-			    voidadd, closeObject ) )
+			    ds->dsEnd.dpStroff,
+			    addedString, addedStrlen, addedAttribute ) )
 	    { LDEB(addedStrlen); return -1;	}
 	}
 
@@ -970,12 +939,15 @@ static int docSplitParaItemLow(	BufferDocument *	bd,
 
     unsigned int		fieldUpd= FIELDdoNOTHING;
 
+    PropertyMask		ppChgMask;
+    PropertyMask		ppUpdMask;
+
     if  ( docEditClaimFieldParticules( &fieldParticules,
 						oldBi->biParaParticuleCount ) )
 	{ LDEB(oldBi->biParaParticuleCount); return -1; }
 
     /*  a,b  */
-    if  ( docFindParticule( oldBi, stroff, &part, /* lastOne */ 0 ) )
+    if  ( docFindParticule( &part, oldBi, stroff, /* lastOne */ 0 ) )
 	{ LLDEB(oldBi->biParaStrlen,stroff); return -1; }
 
     tp= oldBi->biParaParticules+ part;
@@ -986,9 +958,14 @@ static int docSplitParaItemLow(	BufferDocument *	bd,
     if  ( ! newBi )
 	{ XDEB(newBi); return -1;	}
 
+    PROPmaskCLEAR( &ppChgMask );
+
+    PROPmaskCLEAR( &ppUpdMask );
+    PROPmaskFILL( &ppUpdMask, PPprop_COUNT );
+
     /*  1a  */
-    if  ( docCopyParagraphProperties( &(newBi->biParaProperties),
-						&(oldBi->biParaProperties) ) )
+    if  ( docUpdParaProperties( &ppChgMask, &(newBi->biParaProperties),
+				    &ppUpdMask, &(oldBi->biParaProperties) ) )
 	{ LDEB(oldBi->biParaTabCount); return -1;	}
 
     /*  2  */
@@ -1067,6 +1044,7 @@ static int docSplitParaItemLow(	BufferDocument *	bd,
 		break;
 
 	    case DOCkindOBJECT:
+	    case DOCkindNOTE:
 	    case DOCkindTEXT:
 	    case DOCkindTAB:
 	    case DOCkindLINEBREAK:
@@ -1162,72 +1140,6 @@ int docSplitParaItem(		BufferDocument *	bd,
     return rval;
     }
 
-int docSplitGroupItem(	const BufferDocument *	bd,
-			BufferItem **		pNewBi,
-			BufferItem *		oldBi,
-			int			n )
-    {
-    int			i;
-    BufferItem *	newBi;
-
-    if  ( ! oldBi->biParent )
-	{ XDEB(oldBi->biParent); return -1;	}
-    if  ( n < 1 || n >= oldBi->biChildCount )
-	{ LLDEB(n,oldBi->biChildCount); return -1;	}
-
-    newBi= docInsertItem( bd, oldBi->biParent,
-				oldBi->biNumberInParent, oldBi->biLevel );
-    if  ( ! newBi )
-	{ XDEB(newBi); return -1;	}
-
-    switch( oldBi->biLevel )
-	{
-	case DOClevSECT:
-	    if  ( docCopySectionProperties( &newBi->biSectProperties,
-						&oldBi->biSectProperties ) )
-		{ LDEB(1); return -1;	}
-
-	    break;
-	case DOClevCELL:
-	    break;
-	case DOClevROW:
-	    if  ( oldBi->biRowHasTableParagraphs )
-		{
-		LLDEB(oldBi->biLevel,oldBi->biRowHasTableParagraphs);
-		return -1;
-		}
-
-	    if  ( docCopyRowProperties( &newBi->biRowProperties,
-						&oldBi->biRowProperties ) )
-		{ LDEB(1); return -1;	}
-
-	    break;
-	default:
-	    LDEB(oldBi->biLevel); return -1;
-	}
-
-    newBi->biChildren= (BufferItem **)malloc( n* sizeof(BufferItem *) );
-    if  ( ! newBi->biChildren )
-	{ XDEB(newBi->biChildren); return -1;	}
-
-    for ( i= 0; i < n; i++ )
-	{
-	newBi->biChildren[i]= oldBi->biChildren[i];
-	newBi->biChildren[i]->biParent= newBi;
-	}
-
-    newBi->biChildCount= n;
-    oldBi->biChildCount -= n;
-
-    for ( i= 0; i < oldBi->biChildCount; i++ )
-	{
-	oldBi->biChildren[i]= oldBi->biChildren[i+ n];
-	oldBi->biChildren[i]->biNumberInParent -= n;
-	}
-
-    *pNewBi= newBi; return 0;
-    }
-
 /************************************************************************/
 /*									*/
 /*  Insert a tab.							*/
@@ -1350,7 +1262,8 @@ TextParticule * docParaSpecialParticule(BufferItem *		bi,
 /*									*/
 /************************************************************************/
 
-static void docCloseParaObjects(	BufferDocument *	bd,
+static void docCloseParaObjects(	int *			pNoteCount,
+					BufferDocument *	bd,
 					BufferItem *		bi,
 					void *			voidadd,
 					DOC_CLOSE_OBJECT	closeObject )
@@ -1358,20 +1271,25 @@ static void docCloseParaObjects(	BufferDocument *	bd,
     int			part;
     TextParticule *	tp;
 
+    int			noteCount= 0;
+
     tp= bi->biParaParticules;
     for ( part= 0; part < bi->biParaParticuleCount; tp++, part++ )
 	{
-	if  ( tp->tpKind != DOCkindOBJECT	||
-	      tp->tpPhysicalFont != 0		)
-	    { continue;	}
+	if  ( tp->tpKind == DOCkindNOTE )
+	    { noteCount++;	}
 
-	(*closeObject)( bd, bi, tp, voidadd );
+	if  ( tp->tpKind == DOCkindOBJECT )
+	    { (*closeObject)( bd, bi, tp, voidadd );	}
 	}
 
+    *pNoteCount += noteCount;
     return;
     }
 
-void docCloseItemObjects(	BufferDocument *	bd,
+void docCloseItemObjects(	int *			pNoteCount,
+				int *			pParagraphCount,
+				BufferDocument *	bd,
 				BufferItem *		bi,
 				void *			voidadd,
 				DOC_CLOSE_OBJECT	closeObject )
@@ -1386,13 +1304,17 @@ void docCloseItemObjects(	BufferDocument *	bd,
 	case DOClevCELL:
 	    for ( i= 0; i < bi->biChildCount; i++ )
 		{
-		docCloseItemObjects( bd, bi->biChildren[i],
+		docCloseItemObjects( pNoteCount, pParagraphCount,
+						    bd, bi->biChildren[i],
 						    voidadd, closeObject );
 		}
 	    break;
+
 	case DOClevPARA:
-	    docCloseParaObjects( bd, bi, voidadd, closeObject );
+	    docCloseParaObjects( pNoteCount, bd, bi, voidadd, closeObject );
+	    (*pParagraphCount)++;
 	    break;
+
 	default:
 	    LDEB(bi->biLevel); return;
 	}
@@ -1400,3 +1322,92 @@ void docCloseItemObjects(	BufferDocument *	bd,
     return;
     }
 
+/************************************************************************/
+/*									*/
+/*  Delete some buffer items but first close the objects in them.	*/
+/*									*/
+/*  1)  Preliminary administration for shifting the bottom of the range	*/
+/*	of paragraphs that are to be reformatted.			*/
+/*  2)  Include the whole of the parent in the range of items to be	*/
+/*	reformatted.							*/
+/*									*/
+/************************************************************************/
+
+void docEditDeleteItems(	EditOperation *		eo,
+				BufferItem *		bi,
+				int			first,
+				int			count )
+    {
+    int		i;
+    int		f= first;
+
+    int		firstDeleted= -1;
+    int		paragraphsDeleted= 0;
+    int		notesDeleted= 0;
+
+    if  ( count > 0 )
+	{
+	DocumentPosition	dp;
+
+	/*  1  */
+	if  ( docFirstPosition( &dp, bi->biChildren[f] ) )
+	    { LDEB(1);						}
+	else{ firstDeleted= docNumberOfParagraph( dp.dpBi );	}
+
+	/*  2  */
+	docEditIncludeItemInReformatRange( eo, bi );
+	}
+
+    for ( i= 0; i < count; f++, i++ )
+	{
+	docCloseItemObjects( &notesDeleted, &paragraphsDeleted,
+					eo->eoBd, bi->biChildren[f],
+					eo->eoVoidadd, eo->eoCloseObject );
+	}
+
+    eo->eoParagraphsDeleted += paragraphsDeleted;
+    eo->eoNotesDeleted += notesDeleted;
+
+    docDeleteItems( eo->eoBd, bi, first, count );
+
+    if  ( firstDeleted < 0 )
+	{ LDEB(firstDeleted);	}
+    else{
+	docEditShiftReformatRangeParaNr( eo,
+					firstDeleted+ paragraphsDeleted,
+					-paragraphsDeleted );
+	}
+
+    return;
+    }
+
+/************************************************************************/
+/*									*/
+/*  Make a paragraph empty by deleting its contents.			*/
+/*									*/
+/************************************************************************/
+
+int docEditMakeParagraphEmpty(		BufferItem *		paraBi,
+					EditOperation *		eo )
+    {
+    TextParticule *	tp= paraBi->biParaParticules;
+    TextAttribute	ta= tp->tpTextAttribute;
+
+    int			notesDeleted= 0;
+
+    paraBi->biParaStrlen= 0;
+
+    docCloseParaObjects( &notesDeleted,
+			eo->eoBd, paraBi, eo->eoVoidadd, eo->eoCloseObject );
+
+    eo->eoNotesDeleted += notesDeleted;
+
+    docDeleteParticules( paraBi, 0, paraBi->biParaParticuleCount );
+    docDeleteLines( paraBi, 0, paraBi->biParaLineCount );
+
+    if  ( ! docInsertTextParticule( paraBi, 0, 0, 0, DOCkindTEXT, ta ) )
+	{ LDEB(1); return -1;	}
+
+    return 0;
+    }
+
