@@ -1,10 +1,10 @@
 /************************************************************************/
 /*									*/
-/*  Buffer administration routines.					*/
+/*  Buffer administration: manage embedded objects.			*/
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"tedConfig.h"
 
 #   include	<stdlib.h>
 #   include	<string.h>
@@ -41,8 +41,8 @@ static void docInitObject(	InsertedObject *	io )
     io->ioTwipsWide= 0;
     io->ioTwipsHigh= 0;
 
-    io->ioXExtent= 0;
-    io->ioYExtent= 0;
+    io->io_xWinExt= 0;
+    io->io_yWinExt= 0;
 
     io->ioPixelsWide= 0;
     io->ioPixelsHigh= 0;
@@ -59,6 +59,9 @@ static void docInitObject(	InsertedObject *	io )
     io->ioDragWide= 0;
     io->ioDragHigh= 0;
 
+    io->ioMapMode= -1;
+    io->ioResultMapMode= -1;
+
     utilInitMemoryBuffer( &io->ioObjectData );
     utilInitMemoryBuffer( &io->ioResultData );
     
@@ -149,8 +152,8 @@ InsertedObject * docClaimObjectCopy(	BufferItem *		bi,
     ioTo->ioScaleY= ioFrom->ioScaleY;
     ioTo->ioPixelsWide= ioFrom->ioPixelsWide;
     ioTo->ioPixelsHigh= ioFrom->ioPixelsHigh;
-    ioTo->ioXExtent= ioFrom->ioXExtent;
-    ioTo->ioYExtent= ioFrom->ioYExtent;
+    ioTo->io_xWinExt= ioFrom->io_xWinExt;
+    ioTo->io_yWinExt= ioFrom->io_yWinExt;
     ioTo->ioUnitsPerInch= ioFrom->ioUnitsPerInch;
 
     ioTo->ioBliptag= ioFrom->ioBliptag; /*?*/
@@ -158,6 +161,9 @@ InsertedObject * docClaimObjectCopy(	BufferItem *		bi,
     ioTo->ioDragWide= 0;
     ioTo->ioDragHigh= 0;
 
+    ioTo->ioMapMode= ioFrom->ioMapMode;
+    ioTo->ioResultMapMode= ioFrom->ioResultMapMode;
+
     return ioTo;
     }
 
@@ -314,6 +320,7 @@ int docCopyParticuleData(	BufferDocument *	bdTo,
 	case DOCkindLINEBREAK:
 	case DOCkindPAGEBREAK:
 	    break;
+
 	case DOCkindOBJECT:
 	    {
 	    InsertedObject *	io;
@@ -370,6 +377,60 @@ int docCopyParticuleData(	BufferDocument *	bdTo,
 
 	    break;
 
+	case DOCkindNOTE:
+	    {
+	    DocumentNote *	dnTo;
+	    DocumentNote *	dnFrom;
+	    BufferItem *	sectBiTo;
+	    int			noteIndex;
+
+	    if  ( biTo->biInExternalItem != DOCinBODY )
+		{
+		LDEB(biTo->biInExternalItem);
+		tpTo->tpKind= DOCkindTAB;
+		break;
+		}
+
+	    sectBiTo= biTo;
+	    while( sectBiTo && sectBiTo->biLevel != DOClevSECT )
+		{ sectBiTo= sectBiTo->biParent;	}
+	    if  ( ! sectBiTo )
+		{ XDEB(sectBiTo); return -1;	}
+
+	    if  ( docGetNote( &dnFrom, bdFrom, biFrom, tpFrom->tpStroff ) < 0 )
+		{ LDEB(tpFrom->tpStroff); return -1;	}
+
+	    noteIndex= docInsertNote( &dnTo, bdTo, biTo, tpTo->tpStroff );
+	    if  ( noteIndex < 0 )
+		{ LLDEB(tpTo->tpStroff,noteIndex); return -1;	}
+
+	    if  ( docGetNote( &dnFrom, bdFrom, biFrom, tpFrom->tpStroff ) < 0 )
+		{ LDEB(tpFrom->tpStroff); return -1;	}
+
+	    if  ( dnFrom->dnExternalItem.eiItem )
+		{
+		const char *	refFileName= (const char *)0;
+		SelectionScope	ss;
+
+		docInitSelectionScope( &ss );
+
+		ss.ssInExternalItem= dnFrom->dnExternalItemKind;
+		ss.ssSectNrExternalTo= sectBiTo->biNumberInParent;
+		ss.ssNoteArrayIndex= noteIndex;
+
+		dnTo->dnExternalItem.eiItem= docCopySectItem( bdTo, bdFrom,
+				    fieldMap, pFieldUpd, (BufferItem *)0, 0,
+				    dnFrom->dnExternalItem.eiItem,
+				    &ss, refFileName );
+
+		if  ( ! dnTo->dnExternalItem.eiItem )
+		    { XDEB(dnTo->dnExternalItem.eiItem); return -1;	}
+		}
+
+	    dnTo->dnExternalItemKind= dnFrom->dnExternalItemKind;
+	    }
+	    break;
+
 	default:
 	    LDEB(tpFrom->tpKind); return -1;
 	}
