@@ -5,7 +5,7 @@
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"tedConfig.h"
 
 #   include	<stdlib.h>
 #   include	<string.h>
@@ -79,7 +79,7 @@ static int docRtfInfoText(	RtfReadingContext *	rrc,
 
     to= saved;
     while( len > 0 )
-	{ *(to++)= rrc->rrcInputMapping[*(text++)]; len--;	}
+	{ *(to++)= *(text++); len--;	}
     *to= '\0';
 
     if  ( *pText )
@@ -92,7 +92,7 @@ static int docRtfInfoText(	RtfReadingContext *	rrc,
 
 static int docRtfTitleText(	RtfReadingContext *	rrc,
 				const unsigned char *	text,
-				int			len	)
+				int			len )
     {
     return docRtfInfoText( rrc, &(rrc->rrcBd->bdProperties.dpTitle),
 								text, len );
@@ -100,7 +100,7 @@ static int docRtfTitleText(	RtfReadingContext *	rrc,
 
 static int docRtfAuthorText(	RtfReadingContext *	rrc,
 				const unsigned char *	text,
-				int			len	)
+				int			len )
     {
     return docRtfInfoText( rrc, &(rrc->rrcBd->bdProperties.dpAuthor),
 								text, len );
@@ -108,7 +108,7 @@ static int docRtfAuthorText(	RtfReadingContext *	rrc,
 
 static int docRtfSubjectText(	RtfReadingContext *	rrc,
 				const unsigned char *	text,
-				int			len	)
+				int			len )
     {
     return docRtfInfoText( rrc, &(rrc->rrcBd->bdProperties.dpSubject),
 								text, len );
@@ -116,7 +116,7 @@ static int docRtfSubjectText(	RtfReadingContext *	rrc,
 
 static int docRtfKeywordsText(	RtfReadingContext *	rrc,
 				const unsigned char *	text,
-				int			len	)
+				int			len )
     {
     return docRtfInfoText( rrc, &(rrc->rrcBd->bdProperties.dpKeywords),
 								text, len );
@@ -124,7 +124,7 @@ static int docRtfKeywordsText(	RtfReadingContext *	rrc,
 
 static int docRtfCommentText(	RtfReadingContext *	rrc,
 				const unsigned char *	text,
-				int			len	)
+				int			len )
     {
     return docRtfInfoText( rrc, &(rrc->rrcBd->bdProperties.dpComment),
 								text, len );
@@ -138,91 +138,53 @@ static int docRtfHlinkbaseText(	RtfReadingContext *	rrc,
 								text, len );
     }
 
-static int docRtfTitleGroup(	SimpleInputStream *	sis,
+static int docRtfDocInfoGroup(	SimpleInputStream *	sis,
 				const RtfControlWord *	rcw,
 				int			arg,
-				RtfReadingContext *	rrc	)
+				RtfReadingContext *	rrc )
     {
+    RtfAddTextParticule		addTextParticule= (RtfAddTextParticule)0;
+
+    switch( rcw->rcwId )
+	{
+	case DPpropTITLE:
+	    addTextParticule= docRtfTitleText;
+	    break;
+
+	case DPpropAUTHOR:
+	    addTextParticule= docRtfAuthorText;
+	    break;
+
+	case DPpropSUBJECT:
+	    addTextParticule= docRtfSubjectText;
+	    break;
+
+	case DPpropKEYWORDS:
+	    addTextParticule= docRtfKeywordsText;
+	    break;
+
+	case DPpropCOMMENT:
+	    addTextParticule= docRtfCommentText;
+	    break;
+
+	case DPpropHLINKBASE:
+	    addTextParticule= docRtfHlinkbaseText;
+	    break;
+
+	default:
+	    SDEB(rcw->rcwWord); return -1;
+	}
+
     if  ( docRtfReadGroup( sis, rcw->rcwLevel,
 				    (RtfControlWord *)0, 0, 0, rrc,
 				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfTitleText ) )
+				    addTextParticule ) )
 	{ SLDEB(rcw->rcwWord,arg); return -1;	}
 
     return 0;
     }
 
-static int docRtfAuthorGroup(	SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfAuthorText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    return 0;
-    }
-
-static int docRtfSubjectGroup(	SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfSubjectText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    return 0;
-    }
-
-static int docRtfKeywordsGroup(	SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfKeywordsText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    return 0;
-    }
-
-static int docRtfCommentGroup(	SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfCommentText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    return 0;
-    }
-
-static int docRtfHlinkbaseGroup( SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfHlinkbaseText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    return 0;
-    }
-
-static int docRtfCreatimGroup(	SimpleInputStream *	sis,
+static int docRtfDocTimeGroup(	SimpleInputStream *	sis,
 				const RtfControlWord *	rcw,
 				int			arg,
 				RtfReadingContext *	rrc	)
@@ -235,59 +197,39 @@ static int docRtfCreatimGroup(	SimpleInputStream *	sis,
 				    docRtfRefuseText ) )
 	{ SLDEB(rcw->rcwWord,arg); return -1;	}
 
-    rrc->rrcBd->bdProperties.dpCreatim= rrc->rrcTm;
+    switch( rcw->rcwId )
+	{
+	case DPpropCREATIM:
+	    rrc->rrcBd->bdProperties.dpCreatim= rrc->rrcTm;
+	    break;
 
-    return 0;
-    }
+	case DPpropREVTIM:
+	    rrc->rrcBd->bdProperties.dpRevtim= rrc->rrcTm;
+	    break;
 
-static int docRtfRevtimGroup(	SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    appInvalidateTime( &(rrc->rrcTm) );
+	case DPpropPRINTIM:
+	    rrc->rrcBd->bdProperties.dpPrintim= rrc->rrcTm;
+	    break;
 
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfRefuseText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    rrc->rrcBd->bdProperties.dpRevtim= rrc->rrcTm;
-
-    return 0;
-    }
-
-static int docRtfPrintimGroup(	SimpleInputStream *	sis,
-				const RtfControlWord *	rcw,
-				int			arg,
-				RtfReadingContext *	rrc	)
-    {
-    appInvalidateTime( &(rrc->rrcTm) );
-
-    if  ( docRtfReadGroup( sis, rcw->rcwLevel,
-				    (RtfControlWord *)0, 0, 0, rrc,
-				    docRtfEmptyTable, docRtfEmptyTable,
-				    docRtfRefuseText ) )
-	{ SLDEB(rcw->rcwWord,arg); return -1;	}
-
-    rrc->rrcBd->bdProperties.dpPrintim= rrc->rrcTm;
+	default:
+	    SDEB(rcw->rcwWord); return -1;
+	}
 
     return 0;
     }
 
 static RtfControlWord	docRtfInfoGroups[]=
     {
-	{ "title",	RTFidTITLE,	DOClevDOC, docRtfTitleGroup, },
-	{ "author",	RTFidAUTHOR,	DOClevDOC, docRtfAuthorGroup, },
-	{ "subject",	RTFidSUBJECT,	DOClevDOC, docRtfSubjectGroup, },
-	{ "keywords",	RTFidKEYWORDS,	DOClevDOC, docRtfKeywordsGroup, },
-	{ "comment",	RTFidCOMMENT,	DOClevDOC, docRtfCommentGroup, },
-	{ "hlinkbase",	RTFidHLINKBASE,	DOClevDOC, docRtfHlinkbaseGroup, },
+	{ "title",	DPpropTITLE,	DOClevDOC, docRtfDocInfoGroup,	},
+	{ "author",	DPpropAUTHOR,	DOClevDOC, docRtfDocInfoGroup,	},
+	{ "subject",	DPpropSUBJECT,	DOClevDOC, docRtfDocInfoGroup,	},
+	{ "keywords",	DPpropKEYWORDS,	DOClevDOC, docRtfDocInfoGroup,	},
+	{ "comment",	DPpropCOMMENT,	DOClevDOC, docRtfDocInfoGroup,	},
+	{ "hlinkbase",	DPpropHLINKBASE,DOClevDOC, docRtfDocInfoGroup,	},
 
-	{ "creatim",	RTFidCREATIM,	DOClevDOC, docRtfCreatimGroup, },
-	{ "revtim",	RTFidREVTIM,	DOClevDOC, docRtfRevtimGroup, },
-	{ "printim",	RTFidPRINTIM,	DOClevDOC, docRtfPrintimGroup, },
+	{ "creatim",	DPpropCREATIM,	DOClevDOC, docRtfDocTimeGroup, },
+	{ "revtim",	DPpropREVTIM,	DOClevDOC, docRtfDocTimeGroup, },
+	{ "printim",	DPpropPRINTIM,	DOClevDOC, docRtfDocTimeGroup, },
 
 	{ "operator",	RTFidOPERATOR,	DOClevDOC, docRtfSkipGroup, },
 	{ "version",	RTFidVERSION,	DOClevDOC, docRtfSkipGroup, },
