@@ -1,10 +1,13 @@
 /************************************************************************/
 /*									*/
-/*  A Format Tool.							*/
+/*  The 'Format Tool':							*/
+/*									*/
+/*  An inpector with pages for the different formatting properties of	*/
+/*  the document.							*/
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"tedConfig.h"
 
 #   include	<stdlib.h>
 #   include	<stdio.h>
@@ -27,7 +30,7 @@
 
 typedef struct TedFormatToolResources
     {
-    InspectorSubjectResources	tttrSubjectResources[TEDtsiCOUNT];
+    InspectorSubjectResources	tttrSubjectResources[TEDtsi_COUNT];
 
     TablePageResources		tttrTablePageResources;
     RowPageResources		tttrRowPageResources;
@@ -38,48 +41,9 @@ typedef struct TedFormatToolResources
     PageLayoutPageResources	tttrPageLayoutPageResources;
     HeaderFooterPageResources	tttrHeadFootPageResources;
     NotesPageResources		tttrNotesPageResources;
+    TabsPageResources		tttrTabsPageResources;
     } TedFormatToolResources;
 
-static AppConfigurableResource TED_TedFormatToolResourceTable[]=
-    {
-	/****************************************************************/
-	/*  'Table' page.						*/
-	/****************************************************************/
-	APP_RESOURCE( "tableToolTable",
-		    offsetof(TedFormatToolResources,
-		    tttrSubjectResources[TEDtsiTABLE].isrSubjectName),
-		    "Table" ),
-	APP_RESOURCE( "tableToolChangeTable",
-		    offsetof(TedFormatToolResources,
-		    tttrSubjectResources[TEDtsiTABLE].isrApplyToSubject),
-		    "Apply to Table" ),
-	APP_RESOURCE( "tableToolRevert",
-		    offsetof(TedFormatToolResources,
-		    tttrSubjectResources[TEDtsiTABLE].isrRevert),
-		    "Revert" ),
-	/*  no Next Table */
-	/*  no Prev Table */
-	APP_RESOURCE( "tableToolSelectTable",
-		    offsetof(TedFormatToolResources,
-		    tttrSubjectResources[TEDtsiTABLE].isrSelectButtonText),
-		    "Select Table" ),
-	APP_RESOURCE( "tableToolDeleteTable",
-		    offsetof(TedFormatToolResources,
-		    tttrSubjectResources[TEDtsiTABLE].isrDeleteButtonText),
-		    "Delete Table" ),
-	/*  no Insert Table */
-	/*  no Append Table */
-	/**/
-	APP_RESOURCE( "tableToolCellMargin",
-		    offsetof(TedFormatToolResources,
-		    tttrTablePageResources.tprCellMargin),
-		    "Cell Margin" ),
-	APP_RESOURCE( "tableToolLeftIndent",
-		    offsetof(TedFormatToolResources,
-		    tttrTablePageResources.tprLeftIndent),
-		    "Left Margin" ),
-    };
-
 /************************************************************************/
 /*									*/
 /*  Validate a dimension						*/
@@ -246,6 +210,12 @@ static void tedFormatFillPages(	const TedFormatToolResources *	tftr,
 			    ai->aiSubjects[TEDtsiPARA].isPage,
 			    &(tftr->tttrSubjectResources[TEDtsiPARA]) );
 
+    tedFormatFillTabsPage( &(tft->tftTabsTool),
+			    &(tftr->tttrTabsPageResources),
+			    &(ai->aiSubjects[TEDtsiTABS]),
+			    ai->aiSubjects[TEDtsiTABS].isPage,
+			    &(tftr->tttrSubjectResources[TEDtsiTABS]) );
+
     tedFormatFillSectionPage( &(tft->tftSectionTool),
 			    &(tftr->tttrSectPageResources),
 			    &(ai->aiSubjects[TEDtsiSECT]),
@@ -289,11 +259,12 @@ static void tedDestroyFormatTool(	void *	voidtft )
     RowTool *		rt= &(tft->tftRowTool);
     ColumnTool *	cot= &(tft->tftColumnTool);
     CellTool *		clt= &(tft->tftCellTool);
-    TableTool *		tt= &(tft->tftTableTool);
+    TableTool *		tblt= &(tft->tftTableTool);
     SectionTool *	st= &(tft->tftSectionTool);
     PageLayoutTool *	plt= &(tft->tftPageLayoutTool);
     HeaderFooterTool *	hft= &(tft->tftHeaderFooterTool);
     NotesTool *		nt= &(tft->tftNotesTool);
+    TabsTool *		tbst= &(tft->tftTabsTool);
 
     EditApplication *	ea= tft->tftApplication;
     TedAppResources *	tar= (TedAppResources *)ea->eaResourceData;
@@ -306,6 +277,11 @@ static void tedDestroyFormatTool(	void *	voidtft )
     tedFormatCleanBorderTool( &(pt->ptTopBorderTool) );
     tedFormatCleanBorderTool( &(pt->ptBottomBorderTool) );
 
+    docCleanDocumentProperties( &(tbst->ttDocPropertiesSet) );
+    docCleanDocumentProperties( &(tbst->ttDocPropertiesChosen) );
+    docCleanParagraphProperties( &(tbst->ttParaPropertiesSet) );
+    docCleanParagraphProperties( &(tbst->ttParaPropertiesChosen) );
+
     docCleanRowProperties( &(rt->rtPropertiesSet) );
     docCleanRowProperties( &(rt->rtPropertiesChosen) );
     tedFormatCleanBorderTool( &(rt->rtTopBorderTool) );
@@ -326,8 +302,8 @@ static void tedDestroyFormatTool(	void *	voidtft )
     tedFormatCleanBorderTool( &(clt->ctLeftBorderTool) );
     tedFormatCleanBorderTool( &(clt->ctRightBorderTool) );
 
-    docCleanRowProperties( &(tt->ttPropertiesSet) );
-    docCleanRowProperties( &(tt->ttPropertiesChosen) );
+    docCleanRowProperties( &(tblt->ttPropertiesSet) );
+    docCleanRowProperties( &(tblt->ttPropertiesChosen) );
 
     docCleanSectionProperties( &(st->stPropertiesSet) );
     docCleanSectionProperties( &(st->stPropertiesChosen) );
@@ -402,6 +378,10 @@ void tedShowFormatTool(	APP_WIDGET		option,
 
     if  ( ! gotResources )
 	{
+	tedFormatToolGetTableResourceTable( ea,
+				&(tftr.tttrTablePageResources),
+				&(tftr.tttrSubjectResources[TEDtsiTABLE]) );
+
 	tedFormatToolGetRowResourceTable( ea,
 				&(tftr.tttrRowPageResources),
 				&(tftr.tttrSubjectResources[TEDtsiROW]) );
@@ -418,11 +398,15 @@ void tedShowFormatTool(	APP_WIDGET		option,
 				&(tftr.tttrParaPageResources),
 				&(tftr.tttrSubjectResources[TEDtsiPARA]) );
 
+	tedFormatToolGetTabsResourceTable( ea,
+				&(tftr.tttrTabsPageResources),
+				&(tftr.tttrSubjectResources[TEDtsiTABS]) );
+
 	tedFormatToolGetSectResourceTable( ea,
 				&(tftr.tttrSectPageResources),
 				&(tftr.tttrSubjectResources[TEDtsiSECT]) );
 
-	tedFormatToolGetPageResourceTable( ea,
+	appPageLayoutPageGetResourceTable( ea,
 				&(tftr.tttrPageLayoutPageResources),
 				&(tftr.tttrSubjectResources[TEDtsiPAGE]) );
 
@@ -434,11 +418,6 @@ void tedShowFormatTool(	APP_WIDGET		option,
 				&(tftr.tttrNotesPageResources),
 				&(tftr.tttrSubjectResources[TEDtsiNOTES]) );
 
-	appGuiGetResourceValues( ea, (void *)&tftr,
-				TED_TedFormatToolResourceTable,
-				sizeof(TED_TedFormatToolResourceTable)/
-				sizeof(AppConfigurableResource) );
-
 	gotResources= 1;
 	}
 
@@ -456,6 +435,7 @@ void tedShowFormatTool(	APP_WIDGET		option,
     tft->tftRowTool.rtApplication= ea;
     tft->tftTableTool.ttApplication= ea;
     tft->tftNotesTool.ntApplication= ea;
+    tft->tftTabsTool.ttApplication= ea;
 
     appInitDrawingData( &(tft->tftPixmapAdd) );
     tft->tftPixmapAddAllocated= 0;
@@ -466,7 +446,7 @@ void tedShowFormatTool(	APP_WIDGET		option,
 	{ tft->tftBorderPixmaps[i]= (APP_BITMAP_IMAGE)0; }
 
     ai= appMakeInspector( ea, option, pixmapName, widgetName,
-				    tftr.tttrSubjectResources, TEDtsiCOUNT,
+				    tftr.tttrSubjectResources, TEDtsi_COUNT,
 				    tedDestroyFormatTool, (void *)tft );
 
     tft->tftInspector= ai;
@@ -479,6 +459,7 @@ void tedShowFormatTool(	APP_WIDGET		option,
     tft->tftRowTool.rtInspector= ai;
     tft->tftTableTool.ttInspector= ai;
     tft->tftNotesTool.ntInspector= ai;
+    tft->tftTabsTool.ttInspector= ai;
 
     tedFormatFillPages( &tftr, tft, ai );
 
@@ -486,9 +467,10 @@ void tedShowFormatTool(	APP_WIDGET		option,
 					    &(tftr.tttrRowPageResources) );
     tedFormatFillParagraphChoosers( &(tft->tftParagraphTool),
 					    &(tftr.tttrParaPageResources) );
+    tedFormatFillTabsChoosers( &(tft->tftTabsTool) );
     tedFormatFillSectionChoosers( &(tft->tftSectionTool),
 					    &(tftr.tttrSectPageResources) );
-    tedFormatFillPageLayoutChoosers( &(tft->tftPageLayoutTool),
+    appPageLayoutPageFillChoosers( &(tft->tftPageLayoutTool),
 					&(tftr.tttrPageLayoutPageResources) );
     tedFormatFillHeaderFooterChoosers( &(tft->tftHeaderFooterTool),
 					&(tftr.tttrHeadFootPageResources) );
@@ -505,6 +487,7 @@ void tedShowFormatTool(	APP_WIDGET		option,
 					    &(tftr.tttrRowPageResources) );
     tedFormatFinishParagraphPage( &(tft->tftParagraphTool), tft,
 					    &(tftr.tttrParaPageResources) );
+    tedFormatFinishTabsPage( &(tft->tftTabsTool) );
     tedFormatFinishSectionPage( &(tft->tftSectionTool), tft,
 					    &(tftr.tttrSectPageResources) );
     tedFormatFinishPageLayoutPage( &(tft->tftPageLayoutTool), tft,
@@ -543,130 +526,88 @@ void tedFormatShowPagePage(	EditApplication *	ea )
     return;
     }
 
+static void tedFormatRefreshToolPages(	int *				enabled,
+					TedFormatTool *			tft,
+					AppInspector *			ai,
+					BufferDocument *		bd,
+					const DocumentSelection *	ds,
+					const SelectionGeometry *	sg )
+    {
+    tedFormatToolRefreshTableTool( &(tft->tftTableTool),
+				    enabled+ TEDtsiTABLE,
+				    ai->aiSubjects+ TEDtsiTABLE, ds );
+
+    tedFormatToolRefreshColumnTool( &(tft->tftColumnTool),
+				    enabled+ TEDtsiCOLUMN,
+				    ai->aiSubjects+ TEDtsiCOLUMN, ds );
+
+    tedFormatToolRefreshRowTool( &(tft->tftRowTool),
+				    enabled+ TEDtsiROW,
+				    ai->aiSubjects+ TEDtsiROW, ds );
+
+    tedFormatToolRefreshCellTool( &(tft->tftCellTool),
+				    enabled+ TEDtsiCELL,
+				    ai->aiSubjects+ TEDtsiCELL, ds );
+
+    tedFormatToolRefreshParagraphTool(  &(tft->tftParagraphTool),
+				    enabled+ TEDtsiPARA,
+				    ai->aiSubjects+ TEDtsiPARA, ds );
+
+    tedFormatToolRefreshTabsTool( &(tft->tftTabsTool),
+				    enabled+ TEDtsiTABS,
+				    ai->aiSubjects+ TEDtsiTABS,
+				    ds, &(bd->bdProperties) );
+
+    tedFormatToolRefreshSectionTool( &(tft->tftSectionTool),
+				    enabled+ TEDtsiSECT,
+				    ai->aiSubjects+ TEDtsiSECT, ds );
+
+    tedFormatToolRefreshPageLayoutTool( &(tft->tftPageLayoutTool),
+				    enabled+ TEDtsiPAGE,
+				    ai->aiSubjects+ TEDtsiPAGE,
+				    ds, &(bd->bdProperties) );
+
+    tedFormatToolRefreshHeaderFooterTool( &(tft->tftHeaderFooterTool),
+				    enabled+ TEDtsiHEADFOOT,
+				    ai->aiSubjects+ TEDtsiHEADFOOT,
+				    ds, sg, &(bd->bdProperties) );
+
+    tedFormatToolRefreshNotesTool( &(tft->tftNotesTool),
+				    enabled+ TEDtsiNOTES,
+				    ai->aiSubjects+ TEDtsiNOTES,
+				    ds, bd );
+
+    return;
+    }
+
 void tedFormatToolAdaptToSelection( AppInspector *		ai,
-				const BufferDocument *		bd,
-				const SelectionScope *		ss,
-				const BufferSelection *		bs,
+				BufferDocument *		bd,
+				const DocumentSelection *	ds,
+				const SelectionGeometry *	sg,
 				int				fileReadonly )
     {
     TedFormatTool *		tft= (TedFormatTool *)ai->aiTarget;
 
-    TableRectangle		tr;
-
-    int				tableRectangle= 0;
-
     int				subject;
+    int				enabled[TEDtsi_COUNT];
 
-    if  ( ! bs->bsBegin.bpBi )
+    for ( subject= 0; subject < TEDtsi_COUNT; subject++ )
+	{ enabled[subject]= 1;	}
+
+    if  ( ! ds->dsBegin.dpBi )
 	{ appEnableInspector( ai, 0 ); return; }
     else{
-	ParagraphTool *		pt= &(tft->tftParagraphTool);
-	SectionTool *		st= &(tft->tftSectionTool);
-	PageLayoutTool *	plt= &(tft->tftPageLayoutTool);
-	HeaderFooterTool *	hft= &(tft->tftHeaderFooterTool);
-	NotesTool *		nt= &(tft->tftNotesTool);
-
-	tedFormatToolRefreshParagraphTool( pt,
-					ai->aiSubjects+ TEDtsiPARA, bs );
-
-	tedFormatToolRefreshSectionTool( st,
-					ai->aiSubjects+ TEDtsiSECT, bs );
-
-	tedFormatToolRefreshPageLayoutTool( plt,
-					ai->aiSubjects+ TEDtsiPAGE,
-					bs, &(bd->bdProperties) );
-
-	tedFormatToolRefreshHeaderFooterTool( hft,
-					ai->aiSubjects+ TEDtsiHEADFOOT,
-					bs, &(bd->bdProperties) );
-
-	tedFormatToolRefreshNotesTool( nt,
-					ai->aiSubjects+ TEDtsiNOTES,
-					&(bd->bdProperties) );
+	tedFormatRefreshToolPages( enabled, tft, ai, bd, ds, sg );
 
 	if  ( fileReadonly )
 	    { appEnableInspector( ai, 0 );	}
 	else{ appEnableInspector( ai, 1 );	}
 	}
 
-    for ( subject= 0; subject < TEDtsiCOUNT; subject++ )
-	{ appInspectorEnablePage( ai, subject, fileReadonly == 0 ); }
-
-    /*  NotesTool is NOT for 2.9 */
-    appEnableInspectorSubject( ai, TEDtsiNOTES, 0 );
-
-    if  ( ! tedGetTableRectangle( &tr, ss, bs ) )
-	{ tableRectangle= 1;	}
-
-    if  ( tableRectangle )
+    for ( subject= 0; subject < TEDtsi_COUNT; subject++ )
 	{
-	TableTool *	tt= &(tft->tftTableTool);
-	CellTool *	clt= &(tft->tftCellTool);
-	ColumnTool *	cot= &(tft->tftColumnTool);
-	RowTool *	rt= &(tft->tftRowTool);
-
-	tedFormatToolRefreshTableTool( tt, ai->aiSubjects+ TEDtsiTABLE,
-								    &tr, bs );
-
-	appEnableInspectorSubject( ai, TEDtsiTABLE, 1 );
-
-	if  ( tr.trCol1 == tr.trCol0 )
-	    {
-	    tedFormatToolRefreshColumnTool( cot,
-				    ai->aiSubjects+ TEDtsiCOLUMN, &tr, bs );
-
-	    appEnableInspectorSubject( ai, TEDtsiCOLUMN, 1 );
-	    }
-	else{
-	    appEnableInspectorSubject( ai, TEDtsiCOLUMN, 0 );
-	    }
-
-	if  ( tr.trRow1 == tr.trRow0 )
-	    {
-	    appEnableInspectorSubject( ai, TEDtsiROW, 1 );
-
-	    tedFormatToolRefreshRowTool( rt, ai->aiSubjects+ TEDtsiROW,
-								    &tr, bs );
-	    }
-	else{
-	    appEnableInspectorSubject( ai, TEDtsiROW, 0 );
-	    }
-
-	if  ( tr.trCol1 == tr.trCol0 && tr.trRow1 == tr.trRow0 )
-	    {
-	    tedFormatToolRefreshCellTool( clt,
-					ai->aiSubjects+ TEDtsiCELL, &tr, bs );
-
-	    appEnableInspectorSubject( ai, TEDtsiCELL, 1 );
-
-	    /*  CellTool is NOT for 2.9
-	    appEnableInspectorSubject( ai, TEDtsiCELL, 0 );
-	    */
-	    }
-	else{
-	    appEnableInspectorSubject( ai, TEDtsiCELL, 0 );
-	    }
-	}
-    else{
-	docInitTableRectangle( &(tft->tftTableTool.ttTableRectangle) );
-	docInitTableRectangle( &(tft->tftCellTool.ctTableRectangle) );
-	docInitTableRectangle( &(tft->tftColumnTool.ctTableRectangle) );
-	docInitTableRectangle( &(tft->tftRowTool.rtTableRectangle) );
-
-	appEnableInspectorSubject( ai, TEDtsiTABLE, 0 );
-	appEnableInspectorSubject( ai, TEDtsiROW, 0 );
-	appEnableInspectorSubject( ai, TEDtsiCOLUMN, 0 );
-	appEnableInspectorSubject( ai, TEDtsiCELL, 0 );
-	}
-
-    if  ( ss->ssInHeaderFooter != DOCinBODY )
-	{
-	appEnableInspectorSubject( ai, TEDtsiSECT, 0 );
-	appEnableInspectorSubject( ai, TEDtsiPAGE, 0 );
-	}
-    else{
-	appEnableInspectorSubject( ai, TEDtsiSECT, 1 );
-	appEnableInspectorSubject( ai, TEDtsiPAGE, 1 );
+	appEnableInspectorSubject( ai, subject,
+				    enabled[subject] != 0 );
 	}
 
     if  ( ai->aiCurrentSubject < 0				||
