@@ -14,16 +14,6 @@
 /*									*/
 /************************************************************************/
 
-typedef enum WhatPages
-    {
-    PAGES_FIRST_PAGE= 0,
-    PAGES_SUBSEQUENT_PAGES,
-    PAGES_ALL_PAGES,
-    PAGES_ODD_PAGES,
-    PAGES_EVEN_PAGES,
-    PAGES__COUNT
-    } WhatPages;
-
 typedef struct HeaderFooterPageResources
     {
     char *		hfprSectionHeaderText;
@@ -45,38 +35,39 @@ typedef struct HeaderFooterPageResources
 
 typedef struct HeaderFooterTool
     {
-    EditApplication *		hftApplication;
-    AppInspector *		hftInspector;
+    EditApplication *			hftApplication;
+    AppInspector *			hftInspector;
+    const HeaderFooterPageResources *	hftPageResources;
 
-    int				hftSectionNumber;
+    int					hftSectionNumber;
 
-    DocumentProperties		hftDocPropertiesChosen;
-    DocumentProperties		hftDocPropertiesSet;
+    DocumentProperties			hftDocPropertiesChosen;
+    DocumentProperties			hftDocPropertiesSet;
 
-    SectionProperties		hftSectPropertiesChosen;
-    SectionProperties		hftSectPropertiesSet;
-    int				hftPagesChosen;
-    unsigned char		hftPagesOptionsEnabled[PAGES__COUNT];
+    SectionProperties			hftSectPropertiesChosen;
+    SectionProperties			hftSectPropertiesSet;
+    int					hftPagesChosen;
+    unsigned char			hftPagesOptionsEnabled[PAGES__COUNT];
 
-    APP_WIDGET			hftSectionFrame;
-    APP_WIDGET			hftSectionPaned;
-    APP_WIDGET			hftTitlepgToggle;
+    APP_WIDGET				hftSectionFrame;
+    APP_WIDGET				hftSectionPaned;
+    APP_WIDGET				hftTitlepgToggle;
 
-    APP_WIDGET			hftDocumentFrame;
-    APP_WIDGET			hftDocumentPaned;
-    APP_WIDGET			hftFacingpToggle;
-    APP_WIDGET			hftRevertDocButton;
-    APP_WIDGET			hftChangeDocButton;
+    APP_WIDGET				hftDocumentFrame;
+    APP_WIDGET				hftDocumentPaned;
+    APP_WIDGET				hftFacingpToggle;
+    APP_WIDGET				hftRevertDocButton;
+    APP_WIDGET				hftChangeDocButton;
 
-    APP_WIDGET			hftPagesFrame;
-    APP_WIDGET			hftPagesPaned;
-    AppOptionmenu		hftPagesOptionmenu;
-    APP_WIDGET			hftPagesItems[PAGES__COUNT];
+    APP_WIDGET				hftPagesFrame;
+    APP_WIDGET				hftPagesPaned;
+    AppOptionmenu			hftPagesOptionmenu;
+    APP_WIDGET				hftPagesItems[PAGES__COUNT];
 
-    APP_WIDGET			hftDeleteHeaderButton;
-    APP_WIDGET			hftEditHeaderButton;
-    APP_WIDGET			hftDeleteFooterButton;
-    APP_WIDGET			hftEditFooterButton;
+    APP_WIDGET				hftDeleteHeaderButton;
+    APP_WIDGET				hftEditHeaderButton;
+    APP_WIDGET				hftDeleteFooterButton;
+    APP_WIDGET				hftEditFooterButton;
     } HeaderFooterTool;
 
 /************************************************************************/
@@ -85,10 +76,13 @@ typedef struct HeaderFooterTool
 /*									*/
 /************************************************************************/
 
-extern void tedFormatToolRefreshHeaderFooterTool( HeaderFooterTool *	hft,
-						InspectorSubject *	is,
-					const BufferSelection *		bs,
-					const DocumentProperties *	dp );
+extern void tedFormatToolRefreshHeaderFooterTool(
+				HeaderFooterTool *		hft,
+				int *				pEnabled,
+				InspectorSubject *		is,
+				const DocumentSelection *	ds,
+				const SelectionGeometry *	sg,
+				const DocumentProperties *	dp );
 
 extern void tedFormatToolGetHeaderFooterResourceTable( EditApplication * ea,
 					HeaderFooterPageResources *	hfpr,
