@@ -38,30 +38,31 @@ typedef struct SectionPageResources
 
 typedef struct SectionTool
     {
-    EditApplication *		stApplication;
-    AppInspector *		stInspector;
+    EditApplication *			stApplication;
+    AppInspector *			stInspector;
+    const SectionPageResources *	stPageResources;
 
-    int				stUnitType;
+    int					stUnitType;
 
-    SectionProperties		stPropertiesSet;
-    SectionProperties		stPropertiesChosen;
+    SectionProperties			stPropertiesSet;
+    SectionProperties			stPropertiesChosen;
 
-    int				stSectionNumber;
+    int					stSectionNumber;
 
-    APP_WIDGET			stNumberText;
+    APP_WIDGET				stNumberText;
 
-    APP_WIDGET			stPageRestartToggle;
-    APP_WIDGET			stPageRestartText;
+    APP_WIDGET				stPageRestartToggle;
+    APP_WIDGET				stPageRestartText;
 
-    AppOptionmenu		stNumberStyleOptionmenu;
-    APP_WIDGET			stNumberStyleItems[DOCpgn_COUNT];
+    AppOptionmenu			stNumberStyleOptionmenu;
+    APP_WIDGET				stNumberStyleItems[DOCpgn_COUNT];
 
-    AppOptionmenu		stBreakKindOptionmenu;
-    APP_WIDGET			stBreakKindItems[DOCsbk_COUNT];
+    AppOptionmenu			stBreakKindOptionmenu;
+    APP_WIDGET				stBreakKindItems[DOCsbk_COUNT];
 
-    APP_WIDGET			stColumnsText;
-    APP_WIDGET			stColumnSpacingText;
-    APP_WIDGET			stColumnWidthText;
+    APP_WIDGET				stColumnsText;
+    APP_WIDGET				stColumnSpacingText;
+    APP_WIDGET				stColumnWidthText;
     } SectionTool;
 
 /************************************************************************/
@@ -74,4 +75,10 @@ extern void tedFormatToolGetSectResourceTable(	EditApplication *	ea,
 					SectionPageResources *		spr,
 					InspectorSubjectResources *	isr );
 
+extern void tedFormatToolRefreshSectionTool(
+				SectionTool *			st,
+				int *				pEnabled,
+				InspectorSubject *		is,
+				const DocumentSelection *	bs );
+
 #   endif	/*  TED_SECTION_TOOL_H */
