@@ -4,7 +4,7 @@
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"appFrameConfig.h"
 
 #   include	<stddef.h>
 #   include	<stdlib.h>
@@ -522,6 +522,8 @@ static int appMakeFileChooser( AppChooserInformation **	pAci,
     XtSetArg( al[ac], XmNdeleteResponse,	XmDO_NOTHING ); ac++;
     XtSetArg( al[ac], XmNallowShellResize,	True ); ac++;
     XtSetArg( al[ac], XmNuseAsyncGeometry,	True ); ac++;
+    XtSetArg( al[ac], XmNwaitForWm,		False ); ac++; /* LessTif BUG */
+    XtSetArg( al[ac], XmNwmTimeout,		0 ); ac++; /* LessTif BUG */
 
     XtSetArg( al[ac], XmNchildPlacement,XmPLACE_ABOVE_SELECTION ); ac++;
 #   if	XmVersion >= 2000
@@ -684,10 +686,10 @@ static int appChooserOpenDocument(	void *		through,
 					Widget		option,
 					const char *	filename )
     {
-    const int	readonly= 0;
+    const int	read_only= 0;
 
     if  ( ! appOpenDocument( (EditApplication *)through,
-				    relative, option, readonly, filename ) )
+				    relative, option, read_only, filename ) )
 	{ return -1;	}
 
     return 0;
@@ -982,7 +984,7 @@ void appDocFileSaveTo(	APP_WIDGET	option,
 /*									*/
 /************************************************************************/
 
-static int appRunPrintToFileChooser(	Widget			option,
+int appRunPrintToFileChooser(		Widget			option,
 					Widget			panel,
 					EditApplication *	ea,
 					const EditDocument *	ed,
@@ -1024,46 +1026,4 @@ static int appRunPrintToFileChooser(	Widget			option,
     return response;
     }
 
-void appDocPrintToFile(	Widget				option,
-			Widget				panel,
-			EditDocument *			ed,
-			const DocumentGeometry *	dgPaper,
-			int				nup,
-			int				horizontal,
-			int				firstPage,
-			int				lastPage )
-    {
-    EditApplication *	ea= ed->edApplication;
-    int			response;
-    char *		filename;
-
-    FILE *		f;
-
-    if  ( ! ea->eaPrintDocument )
-	{ XDEB(ea->eaPrintDocument); return;	}
-
-    response= appRunPrintToFileChooser( option, panel, ea, ed, &filename );
-
-    switch( response )
-	{
-	case ACIrespCANCEL:
-	    break;
-	case ACIrespSAVE:
-	    f= fopen( filename, "w" );
-
-	    if  ( ! f )
-		{ SXDEB(filename,f); free( filename ); return;	}
-
-	    appCallPrintFunction( f, ed,
-			    dgPaper, nup, horizontal, firstPage, lastPage );
-
-	    fclose( f );
-
-	    free( filename );
-	    break;
-	default:
-	    LDEB(response); break;
-	}
-    }
-
 #   endif
