@@ -1,4 +1,4 @@
-#   include	"config.h"
+#   include	"appFrameConfig.h"
 
 #   include	<stdlib.h>
 #   include	<stdio.h>
@@ -79,7 +79,7 @@ int appGuiInitApplication(	EditApplication *	ea,
     /* 
      * Facilities for making menu option accelerators.
      */
-    gAccelGroup= gAccelGroup = gtk_accel_group_new();
+    gAccelGroup = gtk_accel_group_new();
     gtk_accel_group_attach (gAccelGroup, GTK_OBJECT (gWindow));
     ea->eaToplevel.atAccelGroup= gAccelGroup;
 
@@ -317,6 +317,7 @@ void appMakeLabelInRow(		APP_WIDGET *		pLabel,
 
     gtk_label_set_line_wrap( GTK_LABEL( label ), FALSE );
     gtk_label_set_justify( GTK_LABEL( label ), GTK_JUSTIFY_LEFT );
+    gtk_misc_set_alignment( GTK_MISC( label ), 0.0, 0.5 );
 
     gtk_table_attach( GTK_TABLE( row ),
 			label,
@@ -415,6 +416,7 @@ void appMakeLabelInColumn(	APP_WIDGET *		pLabel,
 
     gtk_label_set_line_wrap( GTK_LABEL( label ), FALSE );
     gtk_label_set_justify( GTK_LABEL( label ), GTK_JUSTIFY_LEFT );
+    gtk_misc_set_alignment( GTK_MISC( label ), 0.0, 0.5 );
 
     gtk_widget_show( label );
 
