@@ -1,4 +1,4 @@
-#   include	"config.h"
+#   include	"appFrameConfig.h"
 
 #   include	<stdlib.h>
 #   include	<stdio.h>
@@ -28,4 +28,23 @@ void appCopyPixmapValue(	APP_SELECTION_EVENT *	gsd,
 
     return;
     }
+
+void appDrawGtkSetXFillRule(	GdkGC *		gc,
+				int		rule )
+    {
+    GdkGCPrivate *	private;
+
+    private = (GdkGCPrivate*)gc;
+
+    switch( rule )
+	{
+	case GDK_EVEN_ODD_RULE:	rule= EvenOddRule; break;
+	case GDK_WINDING_RULE:	rule= WindingRule; break;
+	default:
+	    LDEB(rule); rule= EvenOddRule; break;
+	}
+
+    XSetFillRule( GDK_DISPLAY(), private->xgc, rule );
+    }
+				
 #   endif
