@@ -4,9 +4,10 @@
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"appFrameConfig.h"
 
 #   include	<stdlib.h>
+#   include	<string.h>
 
 #   include	<appGeoString.h>
 #   include	<appPaper.h>
@@ -41,17 +42,25 @@ void appPaperChooserShowWidthHeight(	PaperChooser *		pc,
 /*									*/
 /************************************************************************/
 
-int appPaperChooserGetSize(	unsigned int *		pUpdMask,
+int appPaperChooserGetSize(	PropertyMask *		pChgMask,
 				PaperChooser *		pc,
 				int			unitType,
 				DocumentGeometry *	dg )
     {
     char *		s;
-    unsigned int	updMask= 0;
     DocumentGeometry	dgHere;
 
+    PropertyMask	updMask;
+    PropertyMask	chgMask;
+
     dgHere= *dg;
 
+    PROPmaskCLEAR( &updMask );
+    PROPmaskCLEAR( &chgMask );
+
+    PROPmaskADD( &updMask, DGpropPAGE_WIDTH );
+    PROPmaskADD( &updMask, DGpropPAGE_HEIGHT );
+
     s= appGetStringFromTextWidget( pc->pcSizeText );
 
     if  ( appGeoRectangleFromString( s, unitType,
@@ -69,9 +78,9 @@ int appPaperChooserGetSize(	unsigned int *		pUpdMask,
 
     appFreeStringFromTextWidget( s );
 
-    appSetDocumentGeometry( dg, &dgHere, &updMask, DGupdPAGE_SIZE );
+    appSetDocumentGeometry( dg, &dgHere, &chgMask, &updMask );
 
-    *pUpdMask= updMask;
+    *pChgMask= chgMask;
 
     return 0;
     }
@@ -182,8 +191,8 @@ void appPaperChooserAdaptToGeometry(	PaperChooser *		pc,
 
     if  ( set )
 	{
-	pc->pcLandscapeChosen= pc->pcLandscapeSet;
-	pc->pcSizeChosen= pc->pcSizeSet;
+	pc->pcLandscapeSet= pc->pcLandscapeChosen;
+	pc->pcSizeSet= pc->pcSizeChosen;
 	}
 
     return;
@@ -219,9 +228,11 @@ void appPaperSizeChosen(		APP_WIDGET		w,
 
     if  ( i == pc->pcCustomPaperSize )
 	{
-	unsigned		updMask= 0;
+	PropertyMask		updMask;
 	DocumentGeometry	dgScratch;
 
+	PROPmaskCLEAR( &updMask );
+
 	if  ( appPaperChooserGetSize( &updMask, pc, unitType, &dgScratch ) )
 	    { LDEB(1); return;	}
 
@@ -264,7 +275,9 @@ void appPaperSizeChanged(		PaperChooser *		pc,
 					int			unitType )
     {
     DocumentGeometry	dgScratch;
-    unsigned int	updMask;
+    PropertyMask	updMask;
+
+    PROPmaskCLEAR( &updMask );
 
     dgScratch= *dg;
 
