@@ -8,6 +8,7 @@
 
 #   include	<bitmap.h>
 #   include	<docFont.h>
+#   include	<utilPostscriptFace.h>
 #   include	<appDraw.h>
 #   include	<appImage.h>
 #   include	<sioGeneral.h>
@@ -230,15 +231,51 @@ typedef struct MetaFileObject
 #   define	mfoLogicalFont		mfoSpecific.mfsLogicalFont
 #   define	mfoPatternBrush		mfoSpecific.mfsPatternBrush
 
+/************************************************************************/
+/*									*/
+/*  Refer to Petzold, Charles: "Programming Windows 95", Microsoft	*/
+/*  Press, Redmond, WA, 1996 pp138..					*/
+/*									*/
+/*  Terminology is extremely confusing: The window is the system of	*/
+/*  'logical' user coordinates. The viewport is the sytem of 'hard'	*/
+/*  device coordinates. Viewport=Device coordinates usually are in	*/
+/*  pixels.								*/
+/*									*/
+/************************************************************************/
+
 typedef struct DeviceCoordinateTransform
     {
-    int					dctOrgX;
-    int					dctOrgY;
-    int					dctExtX;
-    int					dctExtY;
+    int					dct_xWinOrg;
+    int					dct_yWinOrg;
+    int					dct_xWinExt;
+    int					dct_yWinExt;
+
+    int					dct_xViewOrg;
+    int					dct_yViewOrg;
+    int					dct_xViewExt;
+    int					dct_yViewExt;
+
     struct DeviceCoordinateTransform *	dctPushed;
     } DeviceCoordinateTransform;
 
+# define DC_xWinOrg(dc)		((dc)->dcTransform.dct_xWinOrg)
+# define DC_yWinOrg(dc)		((dc)->dcTransform.dct_yWinOrg)
+# define DC_xWinExt(dc)		((dc)->dcTransform.dct_xWinExt)
+# define DC_yWinExt(dc)		((dc)->dcTransform.dct_yWinExt)
+
+# define DC_xViewOrg(dc)	((dc)->dcTransform.dct_xViewOrg)
+# define DC_yViewOrg(dc)	((dc)->dcTransform.dct_yViewOrg)
+# define DC_xViewExt(dc)	((dc)->dcTransform.dct_xViewExt)
+# define DC_yViewExt(dc)	((dc)->dcTransform.dct_yViewExt)
+
+# define DC_xViewport(x,dc) ( ( ( x-DC_xWinOrg(dc) )* DC_xViewExt(dc) ) / \
+					    DC_xWinExt(dc)+ DC_xViewOrg(dc) )
+# define DC_yViewport(y,dc) ( ( ( y-DC_yWinOrg(dc) )* DC_yViewExt(dc) ) / \
+					    DC_yWinExt(dc)+ DC_yViewOrg(dc) )
+
+# define DC_wViewport(w,dc) ( ( (w)* DC_xViewExt(dc) ) / DC_xWinExt(dc) )
+# define DC_hViewport(h,dc) ( ( (h)* DC_yViewExt(dc) ) / DC_yWinExt(dc) )
+
 typedef struct DeviceContext
     {
     int				dcMapMode;
@@ -290,29 +327,15 @@ typedef struct DeviceContext
     int				dcObjectCount;
 
     APP_POINT *			dcPoints;
+
     AfmFontInfo *		dcAfi;
+    int				dcFontEncoding;
     } DeviceContext;
 
-# define dcXDct		dcxDeviceContext.dcTransform
-# define dcXExtX	dcXDct.dctExtX
-# define dcXExtY	dcXDct.dctExtY
-# define dcXOrgX	dcXDct.dctOrgX
-# define dcXOrgY	dcXDct.dctOrgY
-
-# define DC_X(x,dc) ( ( (x-(dc)->dcTransform.dctOrgX)* (dc)->dcTwipsWide )/ \
-						    (dc)->dcTransform.dctExtX ) 
-# define DC_Y(y,dc) ( ( (y-(dc)->dcTransform.dctOrgY)* (dc)->dcTwipsHigh )/ \
-						    (dc)->dcTransform.dctExtY )
-
-# define DC_W(w,dc) ( ( (w)* (dc)->dcTwipsWide )/ (dc)->dcTransform.dctExtX ) 
-# define DC_H(h,dc) ( ( (h)* (dc)->dcTwipsHigh )/ (dc)->dcTransform.dctExtY )
-
-# define DCX_X(x,dcx) ( ( (x-(dcx)->dcXOrgX)* (dcx)->dcxPixelsWide )/ \
-							    (dcx)->dcXExtX ) 
-# define DCX_Y(y,dcx) ( ( (y-(dcx)->dcXOrgY)* (dcx)->dcxPixelsHigh )/ \
-							    (dcx)->dcXExtY )
-# define DCX_W(w,dcx) ( ( (w)* (dcx)->dcxPixelsWide )/ (dcx)->dcXExtX ) 
-# define DCX_H(h,dcx) ( ( (h)* (dcx)->dcxPixelsHigh )/ (dcx)->dcXExtY )
+# define DCX_xViewport(x,dcx)	(DC_xViewport(x,&(dcx->dcxDeviceContext)))
+# define DCX_yViewport(y,dcx)	(DC_yViewport(y,&(dcx->dcxDeviceContext)))
+# define DCX_wViewport(w,dcx)	(DC_wViewport(w,&(dcx->dcxDeviceContext)))
+# define DCX_hViewport(h,dcx)	(DC_hViewport(h,&(dcx->dcxDeviceContext)))
 
 typedef struct DeviceContextX11
     {
@@ -343,8 +366,9 @@ extern int appMetaPlayWmfX11(	SimpleInputStream *	sis,
 				AppColors *		ac,
 				AppDrawingData *	add,
 				APP_WINDOW		pixmap,
-				int			xExt,
-				int			yExt,
+				int			mapMode,
+				int			xWinExt,
+				int			yWinExt,
 				int			pixelsWide,
 				int			pixelsHigh,
 				int			twipsWide,
@@ -355,6 +379,7 @@ extern int appMetaPlayEmfX11(	SimpleInputStream *	sis,
 				AppColors *		ac,
 				AppDrawingData *	add,
 				APP_WINDOW		pixmap,
+				int			mapMode,
 				int			xExt,
 				int			yExt,
 				int			pixelsWide,
@@ -369,8 +394,9 @@ extern int appMetaSaveBitmapMetafile(	const BitmapDescription *	bd,
 extern int appMetaPlayFilePs(	FILE *				f,
 				SimpleInputStream *		sis,
 				const char *			afmDirectory,
-				int				xExt,
-				int				yExt,
+				int				mapMode,
+				int				xWinExt,
+				int				yWinExt,
 				int				twipsWide,
 				int				twipsHigh );
 
@@ -378,8 +404,11 @@ extern void appMetaCleanDeviceContext(	DeviceContext *		dc );
 
 extern int appMetaInitDeviceContext(	DeviceContext *		dc,
 					int			objectCount,
-					int			xExt,
-					int			yExt,
+					int			mapMode,
+					int			xWinExt,
+					int			yWinExt,
+					int			xViewExt,
+					int			yViewExt,
 					int			twipsWide,
 					int			twipsHigh );
 
@@ -433,11 +462,11 @@ extern int appMetaCreatePalette(	DeviceContext *		dc,
 extern int appMetaGetColor(		SimpleInputStream *	sis,
 					RGB8Color *		rgb8 );
 
-extern int appMetaListFontsPs(	SimpleInputStream *	sis,
+extern int appMetaListFontsPs(	PostScriptFaceList *	psfl,
+				SimpleInputStream *	sis,
 				const char *		afmDirectory,
 				const char *		prefix,
-				PostScriptFont **	pFontList,
-				int *			pCount,
+				int			mapMode,
 				int			xExt,
 				int			yExt,
 				int			twipsWide,
@@ -457,6 +486,10 @@ extern int appMetaPlayWmfImg(	BitmapDescription *	pBd,
 				unsigned char **	pBuffer,
 				SimpleInputStream *	sis );
 
+extern int appMetaSetMapMode(		DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
 extern int appMetaOffsetWindowOrg(	DeviceContext *		dc,
 					int			recordSize,
 					SimpleInputStream *	sis );
@@ -469,6 +502,22 @@ extern int appMetaSetWindowExt(		DeviceContext *		dc,
 					int			recordSize,
 					SimpleInputStream *	sis );
 
+extern int appMetaSetViewportOrg(	DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
+extern int appMetaSetViewportExt(	DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
+extern int appMetaScaleViewportExt(	DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
+extern int appMetaScaleWindowExt(	DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
 extern int appMetaSaveDC(		DeviceContext *		dc,
 					int			recordSize,
 					SimpleInputStream *	sis );
@@ -489,3 +538,11 @@ extern int appMetaIntersectClipRect(	DeviceContext *		dc,
 					int			recordSize,
 					SimpleInputStream *	sis );
 
+extern int appMetaSetBkColor(		DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
+extern int appMetaSetTextColor(		DeviceContext *		dc,
+					int			recordSize,
+					SimpleInputStream *	sis );
+
