@@ -1,10 +1,10 @@
-#   include	"config.h"
+#   include	"appFrameConfig.h"
 
 #   include	<stddef.h>
 #   include	<stdlib.h>
 
 #   include	<appWinMeta.h>
-#   include	<appPs.h>
+#   include	<utilPs.h>
 #   include	<sioEndian.h>
 
 #   define	y0	math_y0
@@ -55,8 +55,8 @@ static int appMetaGetPointsPs(	DeviceContext *		dc,
 	int	x= sioEndianGetLeInt16( sis );
 	int	y= sioEndianGetLeInt16( sis );
 
-	xp->x= DC_X( x, dc );
-	xp->y= DC_Y( y, dc );
+	xp->x= DC_xViewport( x, dc );
+	xp->y= DC_yViewport( y, dc );
 	}
 
     return 0;
@@ -120,12 +120,12 @@ static void appMetaSetPenPs(		FILE *			f,
 	{
 	case PS_SOLID:
 	  solid:
-	    fprintf( f, "%d setlinewidth ", DC_W( lp->lpWidth, dc ) );
+	    fprintf( f, "%d setlinewidth ", DC_wViewport( lp->lpWidth, dc ) );
 	    fprintf( f, "[] 0 setdash\n" );
 	    break;
 
 	case PS_INSIDEFRAME:
-	    fprintf( f, "%d setlinewidth ", DC_W( lp->lpWidth, dc ) );
+	    fprintf( f, "%d setlinewidth ", DC_wViewport( lp->lpWidth, dc ) );
 	    fprintf( f, "[] 0 setdash\n" );
 	    break;
 
@@ -196,6 +196,11 @@ static int appMetaBitmapImagePs(	SimpleInputStream *	sis,
 					int			dstYExt )
     {
     AppBitmapImage *		abi;
+    BitmapDescription *		bd;
+    double			twipsWide;
+    double			twipsHigh;
+
+    int				dstYExtAbs;
 
     if  ( srcX != 0 || srcY != 0 )
 	{ LLDEB(srcX,srcY); return 0;	}
@@ -203,27 +208,58 @@ static int appMetaBitmapImagePs(	SimpleInputStream *	sis,
     if  ( appMetaBitmapImage( &abi, sis, expectBytes ) )
 	{ LDEB(expectBytes); return -1;	}
 
-    if  ( srcXExt != abi->abiBitmap.bdPixelsWide	||
-	  srcYExt != abi->abiBitmap.bdPixelsHigh	)
+    bd= &(abi->abiBitmap);
+
+    if  ( srcXExt != bd->bdPixelsWide	||
+	  srcYExt != bd->bdPixelsHigh	)
 	{
-	LLDEB(srcXExt,abi->abiBitmap.bdPixelsWide);
-	LLDEB(srcYExt,abi->abiBitmap.bdPixelsHigh);
+	LLDEB(srcXExt,bd->bdPixelsWide);
+	LLDEB(srcYExt,bd->bdPixelsHigh);
 	appCleanBitmapImage( abi ); free( abi );
 	return 0;
 	}
 
-    dstX= DC_X( dstX, dc );
-    dstY= DC_Y( dstY, dc );
+    dstYExtAbs= dstYExt;
+    if  ( dstYExtAbs < 0 )
+	{ dstYExtAbs= -dstYExtAbs;	}
 
-    dstXExt= DC_W( dstXExt, dc );
-    dstYExt= DC_H( dstYExt, dc );
+    switch( bd->bdUnit )
+	{
+	case BMunM:
+	    twipsWide= ( dstXExt* TWIPS_PER_M )/ bd->bdXResolution;
+	    twipsHigh= ( dstYExtAbs* TWIPS_PER_M )/ bd->bdYResolution;
+	    break;
+
+	case BMunINCH:
+	    twipsWide= ( dstXExt* 20* 72 )/ bd->bdXResolution;
+	    twipsHigh= ( dstYExtAbs* 20* 72 )/ bd->bdYResolution;
+	    break;
+
+	case BMunPOINT:
+	    twipsWide= ( dstXExt* 20 )/ bd->bdXResolution;
+	    twipsHigh= ( dstYExtAbs* 20 )/ bd->bdYResolution;
+	    break;
+
+	case BMunPIXEL:
+	    twipsWide= DC_wViewport( dstXExt, dc );
+	    twipsHigh= DC_hViewport( dstYExtAbs, dc );
+	    break;
+
+	default:
+	    SDEB(bmunIntToString(bd->bdUnit));
+	    twipsWide= DC_wViewport( dstXExt, dc );
+	    twipsHigh= DC_hViewport( dstYExtAbs, dc );
+	    break;
+	}
+
+    dstX= DC_xViewport( dstX, dc );
+    dstY= DC_yViewport( dstY, dc );
 
     if  ( bmPsPrintBitmapImage( f, 1,
-			    (double)dstXExt, (double)-dstYExt,
-			    dstX, dstY+ dstYExt, 0, 0,
-			    abi->abiBitmap.bdPixelsWide,
-			    abi->abiBitmap.bdPixelsHigh,
-			    &(abi->abiBitmap), abi->abiBuffer ) )
+			    twipsWide, -twipsHigh,
+			    dstX, ( dstY+ twipsHigh ), 0, 0,
+			    bd->bdPixelsWide, bd->bdPixelsHigh,
+			    bd, abi->abiBuffer ) )
 	{
 	LDEB(1);
 	appCleanBitmapImage( abi ); free( abi );
@@ -432,20 +468,23 @@ static int appMetaSelectFontObjectPs( DeviceContext *		dc,
 
     AppFontFamily *	aff;
     AppFontTypeface *	aft;
+    int			fontEncoding;
 
     DocumentFont *	df;
 
     df= dc->x_dcFontList.dflFonts+ lf->lfTextAttribute.taFontNumber;
 
-    if  ( appGetPsFont( &family, &face, &aff, &aft,
+    if  ( utilFontGetPsFont( &family, &face, &aff, &aft, &fontEncoding,
 				    afmDirectory, df, lf->lfTextAttribute ) )
 	{
 	LDEB(lf->lfTextAttribute.taFontNumber);
 	dc->dcAfi= (AfmFontInfo *)0;
+	dc->dcFontEncoding= -1;
 	return -1;
 	}
 
     dc->dcAfi= (AfmFontInfo *)aft->aftPrintingData;
+    dc->dcFontEncoding= fontEncoding;
 
     dc->dcFont= *lf;
 
@@ -573,8 +612,8 @@ static int appMeta_PolyLinePs(	SimpleInputStream *	sis,
 	int	x= sioEndianGetLeInt16( sis );
 	int	y= sioEndianGetLeInt16( sis );
 
-	x= DC_X( x, dc );
-	y= DC_Y( y, dc );
+	x= DC_xViewport( x, dc );
+	y= DC_yViewport( y, dc );
 
 	fprintf( f, "%d %d %s", x- x0, y- y0, command );
 
@@ -710,10 +749,10 @@ static int appMeta_RectanglePs(	SimpleInputStream *	sis,
     WMFDEB(appDebug("Rectangle(%d..%d,%d..%d)\n", x0,x1,y0,y1));
     WMFLOG(fprintf( f, "%% Rectangle(%d..%d,%d..%d)\n", x0,x1,y0,y1));
 
-    x0= DC_X( x0, dc );
-    y0= DC_Y( y0, dc );
-    x1= DC_X( x1, dc );
-    y1= DC_Y( y1, dc );
+    x0= DC_xViewport( x0, dc );
+    y0= DC_yViewport( y0, dc );
+    x1= DC_xViewport( x1, dc );
+    y1= DC_yViewport( y1, dc );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -767,10 +806,10 @@ static int appMeta_LineToPs(	SimpleInputStream *	sis,
     dc->dcX= x1;
     dc->dcY= y1;
 
-    x0= DC_X( x0, dc );
-    y0= DC_Y( y0, dc );
-    x1= DC_X( x1, dc );
-    y1= DC_Y( y1, dc );
+    x0= DC_xViewport( x0, dc );
+    y0= DC_yViewport( y0, dc );
+    x1= DC_xViewport( x1, dc );
+    y1= DC_yViewport( y1, dc );
 
     if  ( dc->dcDrawBorders )
 	{
@@ -791,6 +830,7 @@ static void appMetaShowStringPs(	FILE *			f,
 					DeviceContext *		dc )
     {
     AfmFontInfo *	afi= dc->dcAfi;
+    int			encoding= dc->dcFontEncoding;
     LogicalFont *	lf= &(dc->dcFont);
 
     int			width;
@@ -805,7 +845,7 @@ static void appMetaShowStringPs(	FILE *			f,
 
     fontSizeTwips= 10* lf->lfTextAttribute.taFontSizeHalfPoints;
     width= psCalculateStringExtents( &abb, dc->dcString, count,
-					    fontSizeTwips, withKerning, afi );
+				fontSizeTwips, withKerning, encoding, afi );
 
     switch( dc->dcTextAlignment & 0x01 )
 	{
@@ -813,8 +853,8 @@ static void appMetaShowStringPs(	FILE *			f,
 	    break;
 
 	case TA_UPDATECP:
-	    x0= DC_X( dc->dcX, dc );
-	    y0= DC_Y( dc->dcY, dc );
+	    x0= DC_xViewport( dc->dcX, dc );
+	    y0= DC_yViewport( dc->dcY, dc );
 	    break;
 
 	default:
@@ -908,14 +948,14 @@ static int appMeta_ExtTextOutPs(	SimpleInputStream *	sis,
 						&x1, &y1, &w1, &h1, dc ) )
 	{ LDEB(1); return -1;	}
 
-    x0= DC_X( x0, dc );
-    y0= DC_Y( y0, dc );
+    x0= DC_xViewport( x0, dc );
+    y0= DC_yViewport( y0, dc );
 
-    x1= DC_X( x1, dc );
-    y1= DC_Y( y1, dc );
+    x1= DC_xViewport( x1, dc );
+    y1= DC_yViewport( y1, dc );
 
-    w1= DC_W( w1, dc );
-    h1= DC_H( h1, dc );
+    w1= DC_wViewport( w1, dc );
+    h1= DC_hViewport( h1, dc );
 
     appMetaShowStringPs( f, x0, y0, count, dc );
 
@@ -934,8 +974,8 @@ static int appMeta_TextOutPs(	SimpleInputStream *	sis,
     if  ( appMeta_TextOut( sis, recordSize, &x0, &y0, &count, dc ) )
 	{ LDEB(1); return -1;	}
 
-    x0= DC_X( x0, dc );
-    y0= DC_Y( y0, dc );
+    x0= DC_xViewport( x0, dc );
+    y0= DC_yViewport( y0, dc );
 
     appMetaShowStringPs( f, x0, y0, count, dc );
 
@@ -970,11 +1010,11 @@ static int appMeta_PatBltPs(	SimpleInputStream *	sis,
     x1= x0+ w0;
     y1= y0+ h0;
 
-    x0= DC_X( x0, dc );
-    y0= DC_Y( y0, dc );
+    x0= DC_xViewport( x0, dc );
+    y0= DC_yViewport( y0, dc );
 
-    x1= DC_X( x1, dc );
-    y1= DC_Y( y1, dc );
+    x1= DC_xViewport( x1, dc );
+    y1= DC_yViewport( y1, dc );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -1035,15 +1075,15 @@ static void appMetaGetArcPs(	SimpleInputStream *	sis,
 
     WMFDEB(appDebug("%s(%d..%d,%d..%d, (%d,%d), (%d,%d)\n", fun,
 					    x0,x1,y0,y1, xs,ys,xe,ye));
-    y0= DC_Y( y0, dc );
-    x0= DC_X( x0, dc );
-    y1= DC_Y( y1, dc );
-    x1= DC_X( x1, dc );
+    y0= DC_yViewport( y0, dc );
+    x0= DC_xViewport( x0, dc );
+    y1= DC_yViewport( y1, dc );
+    x1= DC_xViewport( x1, dc );
 
-    ys= DC_Y( ys, dc );
-    xs= DC_X( xs, dc );
-    ye= DC_Y( ye, dc );
-    xe= DC_X( xe, dc );
+    ys= DC_yViewport( ys, dc );
+    xs= DC_xViewport( xs, dc );
+    ye= DC_yViewport( ye, dc );
+    xe= DC_xViewport( xe, dc );
 
     ym= ( y1+ y0 )/2;
     xm= ( x1+ x0 )/2;
@@ -1233,10 +1273,10 @@ static int appMeta_EllipsePs(	SimpleInputStream *	sis,
 
     WMFDEB(appDebug("Ellipse(%d..%d,%d..%d)\n", x0,x1,y0,y1));
 
-    x0= DC_X( x0, dc );
-    y0= DC_Y( y0, dc );
-    x1= DC_X( x1, dc );
-    y1= DC_Y( y1, dc );
+    x0= DC_xViewport( x0, dc );
+    y0= DC_yViewport( y0, dc );
+    x1= DC_xViewport( x1, dc );
+    y1= DC_yViewport( y1, dc );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -1300,13 +1340,13 @@ static int appMeta_RoundRectPs(	SimpleInputStream *	sis,
     WMFDEB(appDebug("RoundRect(%d..%d,%d..%d, w= %d,h= %d\n",
 					    x0,x1,y0,y1, w, h ));
 
-    y0= DC_Y( y0, dc );
-    x0= DC_X( x0, dc );
-    y1= DC_Y( y1, dc );
-    x1= DC_X( x1, dc );
+    y0= DC_yViewport( y0, dc );
+    x0= DC_xViewport( x0, dc );
+    y1= DC_yViewport( y1, dc );
+    x1= DC_xViewport( x1, dc );
 
-    h= DC_H( h, dc );
-    w= DC_W( w, dc );
+    h= DC_hViewport( h, dc );
+    w= DC_wViewport( w, dc );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -1390,8 +1430,9 @@ static int appMeta_PolyPolygonPs(	SimpleInputStream *	sis,
 int appMetaPlayFilePs(	FILE *				f,
 			SimpleInputStream *		sis,
 			const char *			afmDirectory,
-			int				xExt,
-			int				yExt,
+			int				mapMode,
+			int				xWinExt,
+			int				yWinExt,
 			int				twipsWide,
 			int				twipsHigh )
     {
@@ -1420,8 +1461,10 @@ int appMetaPlayFilePs(	FILE *				f,
     maxRecordSize= sioEndianGetLeInt32( sis );
     parameterCount= sioEndianGetLeInt16( sis );
 
-    if  ( appMetaInitDeviceContext( &dc, objectCount,
-					xExt, yExt, twipsWide, twipsHigh ) )
+    if  ( appMetaInitDeviceContext( &dc, objectCount, mapMode,
+				    xWinExt, yWinExt,
+				    twipsWide, twipsHigh,
+				    twipsWide, twipsHigh ) )
 	{ LDEB(objectCount); return -1;	}
 
     WMFDEB(appDebug( "PS METAFILE ...\n" ));
@@ -1469,6 +1512,16 @@ int appMetaPlayFilePs(	FILE *				f,
 		    { LDEB(1); return -1;	}
 		continue;
 
+	    case WINMETA_SetViewportOrg:
+		if  ( appMetaSetViewportOrg( &dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
+		continue;
+
+	    case WINMETA_SetViewportExt:
+		if  ( appMetaSetViewportExt( &dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
+		continue;
+
 	    case WINMETA_SaveDC:
 		if  ( appMetaSaveDC( &dc, recordSize, sis ) )
 		    { LDEB(1); return -1;	}
@@ -1585,21 +1638,15 @@ int appMetaPlayFilePs(	FILE *				f,
 		continue;
 
 	    case WINMETA_SetBkColor:
-		appMetaGetColor( sis, &(dc.dcBkColor) );
+		if  ( appMetaSetBkColor( &dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
 
-		WMFDEB(appDebug("SetBkColor( r=%d, g=%d, b= %d )\n",
-			    dc.dcBkColor.rgb8Red,
-			    dc.dcBkColor.rgb8Green,
-			    dc.dcBkColor.rgb8Blue ));
 		continue;
 
 	    case WINMETA_SetTextColor:
-		appMetaGetColor( sis, &(dc.dcTextColor) );
+		if  ( appMetaSetTextColor( &dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
 
-		WMFDEB(appDebug("SetTextColor( r=%d, g=%d, b= %d )\n",
-			    dc.dcBkColor.rgb8Red,
-			    dc.dcBkColor.rgb8Green,
-			    dc.dcBkColor.rgb8Blue ));
 		continue;
 
 	    case WINMETA_SetBkMode:
@@ -1680,6 +1727,7 @@ int appMetaPlayFilePs(	FILE *				f,
 		dc.dcY= y0;
 
 		continue;
+
 	    case WINMETA_ExtTextOut:
 		if  ( appMeta_ExtTextOutPs( sis, f, recordSize, &dc ) )
 		    { LDEB(recordSize); return -1;	}
@@ -1729,8 +1777,7 @@ int appMetaPlayFilePs(	FILE *				f,
 		continue;
 
 	    case WINMETA_SetMapMode:
-		dc.dcMapMode= sioEndianGetLeInt16( sis );
-		WMFDEB(appDebug("SetMapMode(%d)\n", dc.dcMapMode ));
+		appMetaSetMapMode( &dc, recordSize, sis );
 		continue;
 
 	    case WINMETA_SetROP2:
@@ -1747,27 +1794,29 @@ int appMetaPlayFilePs(	FILE *				f,
 		    continue;
 		    }
 		XLDEB(function,recordSize); return -1;
+
 	    case WINMETA_SelectPalette:
 		ob= sioEndianGetLeInt16( sis );
 		WMFDEB(appDebug("SelectPalette(%d)\n", ob ));
 		continue;
+
 	    case WINMETA_RealizePalette:
 		WMFDEB(appDebug("RealizePalette()\n"));
 		continue;
+
 	    case WINMETA_PolyPolygon:
 		if  ( appMeta_PolyPolygonPs( sis, f, recordSize, &dc ) )
 		    { LDEB(1); return -1;	}
 		continue;
 
 	    case WINMETA_ScaleViewportExt:
-		x0= sioEndianGetLeInt16( sis );
-		y0= sioEndianGetLeInt16( sis );
-		x1= sioEndianGetLeInt16( sis );
-		y1= sioEndianGetLeInt16( sis );
+		appMetaScaleViewportExt( &dc, recordSize, sis );
+		continue;
+
+	    case WINMETA_ScaleWindowExt:
+		appMetaScaleViewportExt( &dc, recordSize, sis );
+		continue;
 
-		WMFDEB(appDebug("ScaleViewportExt(%d..%d,%d..%d)\n",
-								x0,x1,y0,y1));
-		break;
 	    case 0:
 		if  ( recordSize != 3 )
 		    { XLDEB(function,recordSize); return -1;	}
@@ -1804,13 +1853,13 @@ int appMetaPlayFilePs(	FILE *				f,
 /*									*/
 /************************************************************************/
 
-int appMetaListFontsPs( SimpleInputStream *	sis,
+int appMetaListFontsPs( PostScriptFaceList *	psfl,
+			SimpleInputStream *	sis,
 			const char *		afmDirectory,
 			const char *		prefix,
-			PostScriptFont **	pFontList,
-			int *			pCount,
-			int			xExt,
-			int			yExt,
+			int			mapMode,
+			int			xWinExt,
+			int			yWinExt,
 			int			twipsWide,
 			int			twipsHigh )
     {
@@ -1836,8 +1885,10 @@ int appMetaListFontsPs( SimpleInputStream *	sis,
     maxRecordSize= sioEndianGetLeInt32( sis );
     parameterCount= sioEndianGetLeInt16( sis );
 
-    if  ( appMetaInitDeviceContext( &dc, objectCount,
-					xExt, yExt, twipsWide, twipsHigh ) )
+    if  ( appMetaInitDeviceContext( &dc, objectCount, mapMode,
+						    xWinExt, yWinExt,
+						    twipsWide, twipsHigh,
+						    twipsWide, twipsHigh ) )
 	{ LDEB(objectCount); return -1;	}
 
     WMFDEB(appDebug( "PS METAFILE FONTS ...\n" ));
@@ -1859,6 +1910,7 @@ int appMetaListFontsPs( SimpleInputStream *	sis,
 
 	DocumentFont *		df;
 	AfmFontInfo *		afi;
+	int			encoding;
 
 	const int		appearsInText= 0;
 
@@ -1877,6 +1929,11 @@ int appMetaListFontsPs( SimpleInputStream *	sis,
 		    { LDEB(1); return -1;	}
 		continue;
 
+	    case WINMETA_SetViewportExt:
+		if  ( appMetaSetViewportExt( &dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
+		continue;
+
 	    case WINMETA_CreateFontIndirect:
 		if  ( appMetaCreateFontIndirect( &dc, recordSize, sis ) )
 		    { LDEB(1); return -1;	}
@@ -1886,14 +1943,14 @@ int appMetaListFontsPs( SimpleInputStream *	sis,
 
 		df= dc.x_dcFontList.dflFonts+ lf->lfTextAttribute.taFontNumber;
 
-		if  ( appGetPsFont( &family, &face, &aff, &aft,
+		if  ( utilFontGetPsFont( &family, &face, &aff, &aft, &encoding,
 				    afmDirectory, df, lf->lfTextAttribute ) )
 		    { LDEB(lf->lfTextAttribute.taFontNumber); return -1; }
 
 		afi= (AfmFontInfo *)aft->aftPrintingData;
 
-		if  ( appPsRememberAfi( afi, lf->lfTextAttribute, prefix,
-					appearsInText, pFontList, pCount ) )
+		if  ( utilRememberPostsciptFace( psfl, encoding, afi,
+				lf->lfTextAttribute, prefix, appearsInText ) )
 		    { SDEB(afi->afiFontName); return -1;	}
 
 		appMetaCleanObject( mfo );
@@ -2256,46 +2313,46 @@ int appMetaDefineProcsetPs(	FILE *		f )
     {
     fprintf( f, "%%%%BeginProcSet AppWmfToPs 1.0 1\n\n" );
 
-    appPsDefineProcedure( f, APPMETAPS_Bp,
+    utilPsDefineProcedure( f, APPMETAPS_Bp,
 		    sizeof(APPMETAPS_Bp)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_Rl,
+    utilPsDefineProcedure( f, APPMETAPS_Rl,
 		    sizeof(APPMETAPS_Rl)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillPrep,
+    utilPsDefineProcedure( f, APPMETAPS_FillPrep,
 		    sizeof(APPMETAPS_FillPrep)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillPattern,
+    utilPsDefineProcedure( f, APPMETAPS_FillPattern,
 		    sizeof(APPMETAPS_FillPattern)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_HatchHorizontal,
+    utilPsDefineProcedure( f, APPMETAPS_HatchHorizontal,
 		    sizeof(APPMETAPS_HatchHorizontal)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_HatchVertical,
+    utilPsDefineProcedure( f, APPMETAPS_HatchVertical,
 		    sizeof(APPMETAPS_HatchVertical)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_HatchFdiagonal,
+    utilPsDefineProcedure( f, APPMETAPS_HatchFdiagonal,
 		    sizeof(APPMETAPS_HatchFdiagonal)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_HatchBdiagonal,
+    utilPsDefineProcedure( f, APPMETAPS_HatchBdiagonal,
 		    sizeof(APPMETAPS_HatchBdiagonal)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillHorizontal,
+    utilPsDefineProcedure( f, APPMETAPS_FillHorizontal,
 		    sizeof(APPMETAPS_FillHorizontal)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillVertical,
+    utilPsDefineProcedure( f, APPMETAPS_FillVertical,
 		    sizeof(APPMETAPS_FillVertical)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillCross,
+    utilPsDefineProcedure( f, APPMETAPS_FillCross,
 		    sizeof(APPMETAPS_FillCross)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillBdiagonal,
+    utilPsDefineProcedure( f, APPMETAPS_FillBdiagonal,
 		    sizeof(APPMETAPS_FillBdiagonal)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillFdiagonal,
+    utilPsDefineProcedure( f, APPMETAPS_FillFdiagonal,
 		    sizeof(APPMETAPS_FillFdiagonal)/sizeof(const char *) );
 
-    appPsDefineProcedure( f, APPMETAPS_FillDiagcross,
+    utilPsDefineProcedure( f, APPMETAPS_FillDiagcross,
 		    sizeof(APPMETAPS_FillDiagcross)/sizeof(const char *) );
 
     fprintf( f, "%%%%EndProcSet\n\n" );
