@@ -1,10 +1,10 @@
-#   include	"config.h"
+#   include	"appFrameConfig.h"
 
 #   include	<stddef.h>
 #   include	<stdlib.h>
 
 #   include	<appWinMeta.h>
-#   include	<appPs.h>
+#   include	<utilPs.h>
 #   include	<sioEndian.h>
 
 #   define	y0	math_y0
@@ -75,8 +75,9 @@ static void appMetaCleanDeviceContextX11(	DeviceContextX11 *	dcx )
 
 static int appMetaInitDeviceContextX11(	DeviceContextX11 *	dcx,
 					int			objectCount,
-					int			xExt,
-					int			yExt,
+					int			mapMode,
+					int			xWinExt,
+					int			yWinExt,
 					int			twipsWide,
 					int			twipsHigh,
 					int			pixelsWide,
@@ -84,8 +85,10 @@ static int appMetaInitDeviceContextX11(	DeviceContextX11 *	dcx,
     {
     DeviceContext *	dc= &(dcx->dcxDeviceContext);
 
-    if  ( appMetaInitDeviceContext( dc, objectCount,
-					xExt, yExt, twipsWide, twipsHigh ) )
+    if  ( appMetaInitDeviceContext( dc, objectCount, mapMode,
+						    xWinExt, yWinExt,
+						    pixelsWide, pixelsHigh,
+						    twipsWide, twipsHigh ) )
 	{ LDEB(objectCount); return -1;	}
 
     dcx->dcxPhysicalFont= (AppPhysicalFont *)0;
@@ -366,11 +369,13 @@ static int appMetaSelectPenObjectX11(	DeviceContextX11 *	dcx,
 
 #	    ifdef USE_MOTIF
 	    XSetLineAttributes( add->addDisplay, add->addGc,
-		    DCX_W( lp->lpWidth, dcx ), LineSolid, CapButt, JoinMiter );
+					    DCX_wViewport( lp->lpWidth, dcx ),
+					    LineSolid, CapButt, JoinMiter );
 #	    endif
 #	    ifdef USE_GTK
-	    gdk_gc_set_line_attributes( add->addGc, DCX_W( lp->lpWidth, dcx ),
-		    GDK_LINE_SOLID, GDK_CAP_PROJECTING, GDK_JOIN_MITER );
+	    gdk_gc_set_line_attributes( add->addGc,
+			DCX_wViewport( lp->lpWidth, dcx ),
+			GDK_LINE_SOLID, GDK_CAP_PROJECTING, GDK_JOIN_MITER );
 #	    endif
 
 	    break;
@@ -382,11 +387,13 @@ static int appMetaSelectPenObjectX11(	DeviceContextX11 *	dcx,
 
 #	    ifdef USE_MOTIF
 	    XSetLineAttributes( add->addDisplay, add->addGc,
-		    DCX_W( lp->lpWidth, dcx ), LineSolid, CapButt, JoinMiter );
+					    DCX_wViewport( lp->lpWidth, dcx ),
+					    LineSolid, CapButt, JoinMiter );
 #	    endif
 #	    ifdef USE_GTK
-	    gdk_gc_set_line_attributes( add->addGc, DCX_W( lp->lpWidth, dcx ),
-		    GDK_LINE_SOLID, GDK_CAP_PROJECTING, GDK_JOIN_MITER );
+	    gdk_gc_set_line_attributes( add->addGc,
+			DCX_wViewport( lp->lpWidth, dcx ),
+			GDK_LINE_SOLID, GDK_CAP_PROJECTING, GDK_JOIN_MITER );
 #	    endif
 
 	    break;
@@ -526,8 +533,8 @@ static int appMetaGetPointsX11(	DeviceContextX11 *	dcx,
 	int	x= sioEndianGetLeInt16( sis );
 	int	y= sioEndianGetLeInt16( sis );
 
-	xp->x= DCX_X( x, dcx );
-	xp->y= DCX_Y( y, dcx );
+	xp->x= DCX_xViewport( x, dcx );
+	xp->y= DCX_yViewport( y, dcx );
 	}
 
     return 0;
@@ -612,13 +619,18 @@ static int appMetaBitmapImageX11(	AppBitmapImage **	pAbi,
     {
     DeviceContext *	dc= &(dcx->dcxDeviceContext);
     AppDrawingData *	add= &(dc->dcDrawingData);
-    AppBitmapImage *	abi;
 
+    AppBitmapImage *	abi;
     BitmapDescription *	bd;
+
+    int			twipsWide;
+    int			twipsHigh;
+    int			pixelsWide;
+    int			pixelsHigh;
+
     APP_IMAGE *		xim= (APP_IMAGE *)0;
 
-    if  ( srcX != 0 || srcY != 0 )
-	{ LLDEB(srcX,srcY); 	}
+    int			dstYExtAbs;
 
     if  ( expectBytes < 40 )
 	{
@@ -632,29 +644,103 @@ static int appMetaBitmapImageX11(	AppBitmapImage **	pAbi,
 	return 0;
 	}
 
+    if  ( srcX != 0 || srcY != 0 )
+	{ LLDEB(srcX,srcY); 	}
+
     if  ( appMetaBitmapImage( &abi, sis, expectBytes ) )
 	{ LDEB(expectBytes); return -1;	}
 
-    if  ( srcXExt != abi->abiBitmap.bdPixelsWide	||
-	  srcYExt != abi->abiBitmap.bdPixelsHigh	)
+    bd= &(abi->abiBitmap);
+
+    if  ( srcXExt != bd->bdPixelsWide	||
+	  srcYExt != bd->bdPixelsHigh	)
 	{
-	LLDEB(srcXExt,abi->abiBitmap.bdPixelsWide);
-	LLDEB(srcYExt,abi->abiBitmap.bdPixelsHigh);
+	LLDEB(srcXExt,bd->bdPixelsWide);
+	LLDEB(srcYExt,bd->bdPixelsHigh);
 	appCleanBitmapImage( abi ); free( abi );
 	return 0;
 	}
 
-    if  ( appImgMakeImage( add, &xim, dstXExt, dstYExt, ac, abi ) )
+    dstYExtAbs= dstYExt;
+    if  ( dstYExtAbs < 0 )
+	{ dstYExtAbs= -dstYExtAbs;	}
+
+    switch( bd->bdUnit )
+	{
+	case BMunM:
+	    twipsWide= ( dstXExt* TWIPS_PER_M )/ bd->bdXResolution;
+	    twipsHigh= ( dstYExtAbs* TWIPS_PER_M )/ bd->bdYResolution;
+
+	    pixelsWide= ( dcx->dcxPixelsWide* twipsWide )/ dc->dcTwipsWide;
+	    pixelsHigh= ( dcx->dcxPixelsHigh* twipsHigh )/ dc->dcTwipsHigh;
+
+	    dstXExt= DC_wViewport( dstXExt, dc );
+	    dstYExt= DC_hViewport( dstYExtAbs, dc );
+
+	    break;
+
+	case BMunINCH:
+	    twipsWide= ( dstXExt* 20* 72 )/ bd->bdXResolution;
+	    twipsHigh= ( dstYExtAbs* 20* 72 )/ bd->bdYResolution;
+
+	    pixelsWide= ( dcx->dcxPixelsWide* twipsWide )/ dc->dcTwipsWide;
+	    pixelsHigh= ( dcx->dcxPixelsHigh* twipsHigh )/ dc->dcTwipsHigh;
+
+	    dstXExt= DC_wViewport( dstXExt, dc );
+	    dstYExt= DC_hViewport( dstYExtAbs, dc );
+	    break;
+
+	case BMunPOINT:
+	    twipsWide= ( dstXExt* 20 )/ bd->bdXResolution;
+	    twipsHigh= ( dstYExtAbs* 20 )/ bd->bdYResolution;
+
+	    pixelsWide= ( dcx->dcxPixelsWide* twipsWide )/ dc->dcTwipsWide;
+	    pixelsHigh= ( dcx->dcxPixelsHigh* twipsHigh )/ dc->dcTwipsHigh;
+
+	    dstXExt= DC_wViewport( dstXExt, dc );
+	    dstYExt= DC_hViewport( dstYExtAbs, dc );
+	    break;
+
+	case BMunPIXEL:
+	    dstXExt= DC_wViewport( dstXExt, dc );
+	    dstYExt= DC_hViewport( dstYExtAbs, dc );
+
+	    pixelsWide= dstXExt;
+	    pixelsHigh= dstYExt;
+	    break;
+
+	default:
+	    SDEB(bmunIntToString(bd->bdUnit));
+	    dstXExt= DC_wViewport( dstXExt, dc );
+	    dstYExt= DC_hViewport( dstYExtAbs, dc );
+
+	    pixelsWide= dstXExt;
+	    pixelsHigh= dstYExt;
+	    break;
+	}
+
+    dstX= DCX_xViewport( dstX, dcx );
+    dstY= DCX_yViewport( dstY, dcx );
+
+    if  ( dstXExt < 0 )
+	{ dstXExt= -dstXExt;	}
+    if  ( dstYExt < 0 )
+	{ dstYExt= -dstYExt;	}
+
+    if  ( appImgMakeImage( add, &xim, pixelsWide, pixelsHigh, ac, abi ) )
 	{ LDEB(1); appCleanBitmapImage( abi ); free( abi ); return -1; }
 
 #   ifdef USE_MOTIF
     XPutImage( add->addDisplay, add->addDrawable, add->addGc,
-			    xim, srcX, srcY, dstX, dstY, dstXExt, dstYExt );
+					    xim, srcX, srcY, dstX, dstY,
+					    pixelsWide, pixelsHigh );
     XDestroyImage( xim );
 #   endif
+
 #   ifdef USE_GTK
     gdk_draw_image( add->addDrawable, add->addGc,
-			    xim, srcX, srcY, dstX, dstY, dstXExt, dstYExt );
+					    xim, srcX, srcY, dstX, dstY,
+					    pixelsWide, pixelsHigh );
     gdk_image_destroy( xim );
 #   endif
 
@@ -783,13 +869,13 @@ static int appMeta_RoundRectX11(	SimpleInputStream *	sis,
     WMFDEB(appDebug("RoundRect(%d..%d,%d..%d, w= %d,h= %d\n",
 					    x0,x1,y0,y1, w, h ));
 
-    y0= DCX_Y( y0, dcx );
-    x0= DCX_X( x0, dcx );
-    y1= DCX_Y( y1, dcx );
-    x1= DCX_X( x1, dcx );
+    y0= DCX_yViewport( y0, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y1= DCX_yViewport( y1, dcx );
+    x1= DCX_xViewport( x1, dcx );
 
-    h= DCX_H( h, dcx );
-    w= DCX_W( w, dcx );
+    h= DCX_hViewport( h, dcx );
+    w= DCX_wViewport( w, dcx );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -943,15 +1029,15 @@ static void appMetaGetArcX11(	SimpleInputStream *	sis,
 
     WMFDEB(appDebug("%s(%d..%d,%d..%d, (%d,%d), (%d,%d)\n", fun,
 					    x0,x1,y0,y1, xs,ys,xe,ye));
-    y0= DCX_Y( y0, dcx );
-    x0= DCX_X( x0, dcx );
-    y1= DCX_Y( y1, dcx );
-    x1= DCX_X( x1, dcx );
+    y0= DCX_yViewport( y0, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y1= DCX_yViewport( y1, dcx );
+    x1= DCX_xViewport( x1, dcx );
 
-    ys= DCX_Y( ys, dcx );
-    xs= DCX_X( xs, dcx );
-    ye= DCX_Y( ye, dcx );
-    xe= DCX_X( xe, dcx );
+    ys= DCX_yViewport( ys, dcx );
+    xs= DCX_xViewport( xs, dcx );
+    ye= DCX_yViewport( ye, dcx );
+    xe= DCX_xViewport( xe, dcx );
 
     ym= ( y1+ y0 )/2;
     xm= ( x1+ x0 )/2;
@@ -1105,10 +1191,10 @@ static int appMeta_EllipseX11(	SimpleInputStream *	sis,
 
     WMFDEB(appDebug("Ellipse(%d..%d,%d..%d)\n", x0,x1,y0,y1));
 
-    x0= DCX_X( x0, dcx );
-    y0= DCX_Y( y0, dcx );
-    x1= DCX_X( x1, dcx );
-    y1= DCX_Y( y1, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y0= DCX_yViewport( y0, dcx );
+    x1= DCX_xViewport( x1, dcx );
+    y1= DCX_yViewport( y1, dcx );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -1185,10 +1271,10 @@ static int appMeta_RectangleX11(	SimpleInputStream *	sis,
 
     WMFDEB(appDebug("Rectangle(%d..%d,%d..%d)\n", x0,x1,y0,y1));
 
-    x0= DCX_X( x0, dcx );
-    y0= DCX_Y( y0, dcx );
-    x1= DCX_X( x1, dcx );
-    y1= DCX_Y( y1, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y0= DCX_yViewport( y0, dcx );
+    x1= DCX_xViewport( x1, dcx );
+    y1= DCX_yViewport( y1, dcx );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -1299,8 +1385,8 @@ static void appMetaDrawStringX11(	int			x0,
 	    break;
 
 	case TA_UPDATECP:
-	    x0= DCX_X( dc->dcX, dcx );
-	    y0= DCX_Y( dc->dcY, dcx );
+	    x0= DCX_xViewport( dc->dcX, dcx );
+	    y0= DCX_yViewport( dc->dcY, dcx );
 	    break;
 
 	default:
@@ -1369,6 +1455,7 @@ static void appMetaDrawStringX11(	int			x0,
 	    break;
 	}
 
+    return;
     }
 
 static int appMeta_ExtTextOutX11(	SimpleInputStream *	sis,
@@ -1389,14 +1476,14 @@ static int appMeta_ExtTextOutX11(	SimpleInputStream *	sis,
 			    &x1, &y1, &w1, &h1, &(dcx->dcxDeviceContext) ) )
 	{ LDEB(1); return -1;	}
 
-    x0= DCX_X( x0, dcx );
-    y0= DCX_Y( y0, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y0= DCX_yViewport( y0, dcx );
 
-    x1= DCX_X( x1, dcx );
-    y1= DCX_Y( y1, dcx );
+    x1= DCX_xViewport( x1, dcx );
+    y1= DCX_yViewport( y1, dcx );
 
-    w1= DCX_W( w1, dcx );
-    h1= DCX_H( h1, dcx );
+    w1= DCX_wViewport( w1, dcx );
+    h1= DCX_hViewport( h1, dcx );
 
     appMetaDrawStringX11( x0, y0, count, dcx );
 
@@ -1415,8 +1502,8 @@ static int appMeta_TextOutX11(	SimpleInputStream *	sis,
 				&x0, &y0, &count, &(dcx->dcxDeviceContext) ) )
 	{ LDEB(1); return -1;	}
 
-    x0= DCX_X( x0, dcx );
-    y0= DCX_Y( y0, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y0= DCX_yViewport( y0, dcx );
 
     appMetaDrawStringX11( x0, y0, count, dcx );
 
@@ -1443,10 +1530,10 @@ static int appMeta_LineToX11(	SimpleInputStream *	sis,
     dc->dcX= x1;
     dc->dcY= y1;
 
-    x0= DCX_X( x0, dcx );
-    y0= DCX_Y( y0, dcx );
-    x1= DCX_X( x1, dcx );
-    y1= DCX_Y( y1, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y0= DCX_yViewport( y0, dcx );
+    x1= DCX_xViewport( x1, dcx );
+    y1= DCX_yViewport( y1, dcx );
 
     appDrawSetForegroundColor( add, &(dcx->dcxPenColor) );
 
@@ -1485,11 +1572,11 @@ static int appMeta_PatBltX11(	SimpleInputStream *	sis,
     x1= x0+ w0;
     y1= y0+ h0;
 
-    x0= DCX_X( x0, dcx );
-    y0= DCX_Y( y0, dcx );
+    x0= DCX_xViewport( x0, dcx );
+    y0= DCX_yViewport( y0, dcx );
 
-    x1= DCX_X( x1, dcx );
-    y1= DCX_Y( y1, dcx );
+    x1= DCX_xViewport( x1, dcx );
+    y1= DCX_yViewport( y1, dcx );
 
     if  ( x1 < x0 )
 	{ swap= x0; x0= x1; x1= swap; }
@@ -1528,7 +1615,7 @@ static int appMeta_SetPolyFillModeX11(	SimpleInputStream *	sis,
 	    XSetFillRule( add->addDisplay, add->addGc, EvenOddRule );
 #	    endif
 #	    ifdef USE_GTK
-	    SLDEB("GDK",mode);
+	    appDrawGtkSetXFillRule( add->addGc, GDK_EVEN_ODD_RULE );
 #	    endif
 	    break;
 
@@ -1539,7 +1626,7 @@ static int appMeta_SetPolyFillModeX11(	SimpleInputStream *	sis,
 	    XSetFillRule( add->addDisplay, add->addGc, WindingRule );
 #	    endif
 #	    ifdef USE_GTK
-	    SLDEB("GDK",mode);
+	    appDrawGtkSetXFillRule( add->addGc, GDK_WINDING_RULE );
 #	    endif
 	    break;
 
@@ -1664,6 +1751,16 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		    { LDEB(1); return -1;	}
 		continue;
 
+	    case WINMETA_SetViewportOrg:
+		if  ( appMetaSetViewportOrg( dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
+		continue;
+
+	    case WINMETA_SetViewportExt:
+		if  ( appMetaSetViewportExt( dc, recordSize, sis ) )
+		    { LDEB(1); return -1;	}
+		continue;
+
 	    case WINMETA_SaveDC:
 		if  ( appMetaSaveDC( dc, recordSize, sis ) )
 		    { LDEB(1); return -1;	}
@@ -1711,12 +1808,6 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		WMFDEB(appDebug("BitBlt([%d+%d,%d+%d]->[%d+%d,%d+%d],..)\n",
 				x0,w0,y0,h0, x1,w1,y1,h1 ));
 
-		x1= DCX_X( x1, dcx );
-		y1= DCX_Y( y1, dcx );
-
-		w1= DCX_W( w1, dcx );
-		h1= DCX_H( h1, dcx );
-
 		if  ( appMetaBitmapImageX11( &abi, sis, 2*(recordSize-3-2-6*1),
 			    dcx, ac, x0, y0, w0, h0, x1, y1, w1, h1 ) )
 		    { LDEB(1); return -1; }
@@ -1739,12 +1830,6 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		WMFDEB(appDebug("StretchBlt([%d+%d,%d+%d]->[%d+%d,%d+%d],..)\n",
 				x0,w0,y0,h0, x1,w1,y1,h1 ));
 
-		x1= DCX_X( x1, dcx );
-		y1= DCX_Y( y1, dcx );
-
-		w1= DCX_W( w1, dcx );
-		h1= DCX_H( h1, dcx );
-
 		if  ( appMetaBitmapImageX11( &abi, sis, 2*(recordSize-3-2-8*1),
 			    dcx, ac, x0, y0, w0, h0, x1, y1, w1, h1 ) )
 		    { LDEB(1); return -1; }
@@ -1769,12 +1854,6 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 			"StretchDIBits([%d+%d,%d+%d]->[%d+%d,%d+%d],..)\n",
 			x0,w0,y0,h0, x1,w1,y1,h1 ));
 
-		x1= DCX_X( x1, dcx );
-		y1= DCX_Y( y1, dcx );
-
-		w1= DCX_W( w1, dcx );
-		h1= DCX_H( h1, dcx );
-
 		if  ( appMetaBitmapImageX11( &abi, sis, 2*(recordSize-3-2-9*1),
 			    dcx, ac, x0, y0, w0, h0, x1, y1, w1, h1 ) )
 		    { LDEB(1); return -1; }
@@ -1830,12 +1909,9 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		continue;
 
 	    case WINMETA_SetBkColor:
-		appMetaGetColor( sis, &(dcx->dcxDeviceContext.dcBkColor) );
-
-		WMFDEB(appDebug("SetBkColor( r=%d, g=%d, b= %d )\n",
-			    dcx->dcxDeviceContext.dcBkColor.rgb8Red,
-			    dcx->dcxDeviceContext.dcBkColor.rgb8Green,
-			    dcx->dcxDeviceContext.dcBkColor.rgb8Blue ));
+		if  ( appMetaSetBkColor( &(dcx->dcxDeviceContext),
+							recordSize, sis ) )
+		    { LDEB(1); return -1;	}
 
 		if  ( appColorRgb( &dcx->dcxBkColor, ac,
 			    dcx->dcxDeviceContext.dcBkColor.rgb8Red,
@@ -1846,12 +1922,9 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		continue;
 
 	    case WINMETA_SetTextColor:
-		appMetaGetColor( sis, &(dcx->dcxDeviceContext.dcTextColor) );
-
-		WMFDEB(appDebug("SetTextColor( r=%d, g=%d, b= %d )\n",
-			    dcx->dcxDeviceContext.dcTextColor.rgb8Red,
-			    dcx->dcxDeviceContext.dcTextColor.rgb8Green,
-			    dcx->dcxDeviceContext.dcTextColor.rgb8Blue ));
+		if  ( appMetaSetTextColor( &(dcx->dcxDeviceContext),
+							recordSize, sis ) )
+		    { LDEB(1); return -1;	}
 
 		if  ( appColorRgb( &dcx->dcxTextColor, ac,
 			    dcx->dcxDeviceContext.dcTextColor.rgb8Red,
@@ -1989,10 +2062,9 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		continue;
 
 	    case WINMETA_SetMapMode:
-		dcx->dcxDeviceContext.dcMapMode= sioEndianGetLeInt16( sis );
-		WMFDEB(appDebug("SetMapMode(%d)\n",
-					    dcx->dcxDeviceContext.dcMapMode ));
+		appMetaSetMapMode( dc, recordSize, sis );
 		continue;
+
 	    case WINMETA_SetROP2:
 		if  ( recordSize == 5 )
 		    {
@@ -2023,18 +2095,17 @@ static int appWinMetaPlayRecords(	SimpleInputStream *	sis,
 		continue;
 
 	    case WINMETA_ScaleViewportExt:
-		x0= sioEndianGetLeInt16( sis );
-		y0= sioEndianGetLeInt16( sis );
-		x1= sioEndianGetLeInt16( sis );
-		y1= sioEndianGetLeInt16( sis );
+		appMetaScaleViewportExt( dc, recordSize, sis );
+		continue;
 
-		WMFDEB(appDebug("ScaleViewportExt(%d..%d,%d..%d)\n",
-								x0,x1,y0,y1));
-		break;
+	    case WINMETA_ScaleWindowExt:
+		appMetaScaleWindowExt( dc, recordSize, sis );
+		continue;
 
 	    case 0:
 		if  ( recordSize != 3 )
 		    { XLDEB(function,recordSize); return -1;	}
+		WMFDEB(appDebug("READY\n"));
 		break;
 
 	    skipArguments:
@@ -2070,8 +2141,9 @@ int appMetaPlayWmfX11(	SimpleInputStream *	sis,
 			AppColors *		ac,
 			AppDrawingData *	parent_add,
 			APP_WINDOW		pixmap,
-			int			xExt,
-			int			yExt,
+			int			mapMode,
+			int			xWinExt,
+			int			yWinExt,
 			int			pixelsWide,
 			int			pixelsHigh,
 			int			twipsWide,
@@ -2102,8 +2174,10 @@ int appMetaPlayWmfX11(	SimpleInputStream *	sis,
     maxRecordSize= sioEndianGetLeInt32( sis );
     parameterCount= sioEndianGetLeInt16( sis );
 
-    appMetaInitDeviceContextX11( &dcx, objectCount,
-		xExt, yExt, twipsWide, twipsHigh, pixelsWide, pixelsHigh );
+    appMetaInitDeviceContextX11( &dcx, objectCount, mapMode,
+						    xWinExt, yWinExt,
+						    twipsWide, twipsHigh,
+						    pixelsWide, pixelsHigh );
 
     pixelsPerTwip= sqrt( (double)( pixelsWide* pixelsHigh )/
 						( twipsWide* twipsHigh ) );
@@ -2120,7 +2194,11 @@ int appMetaPlayWmfX11(	SimpleInputStream *	sis,
 
     appMetaFillBackground( &dcx );
 
-    WMFDEB(appDebug( "X11 WMF ...\n" ));
+    WMFDEB(appDebug(
+		"X11 WMF winExt: [%dx%d], pix: [%dx%d], twips: [%dx%d]\n",
+						    xWinExt, yWinExt,
+						    pixelsWide, pixelsHigh,
+						    twipsWide, twipsHigh ));
 
     if  ( appWinMetaPlayRecords( sis, pPrivate, ac, &dcx ) )
 	{
@@ -2139,6 +2217,7 @@ int appMetaPlayEmfX11(	SimpleInputStream *	sis,
 			AppColors *		ac,
 			AppDrawingData *	parent_add,
 			APP_BITMAP_IMAGE	pixmap,
+			int			mapMode,
 			int			xExt,
 			int			yExt,
 			int			pixelsWide,
@@ -2172,9 +2251,11 @@ int appMetaPlayEmfX11(	SimpleInputStream *	sis,
 
     int			done= 0;
 
+    /*
     if  ( sioInGetCharacter( sis ) == EOF )
 	{ return 0;	}
     sioInUngetLastRead( sis );
+    */
 
     recordType= sioEndianGetLeUint32( sis ); done += 4;
     recordSize= sioEndianGetLeUint32( sis ); done += 4;
@@ -2183,6 +2264,7 @@ int appMetaPlayEmfX11(	SimpleInputStream *	sis,
     boundsRight= sioEndianGetLeInt32( sis ); done += 4;
     boundsTop= sioEndianGetLeInt32( sis ); done += 4;
     boundsBottom= sioEndianGetLeInt32( sis ); done += 4;
+
     frameLeft= sioEndianGetLeInt32( sis ); done += 4;
     frameRight= sioEndianGetLeInt32( sis ); done += 4;
     frameTop= sioEndianGetLeInt32( sis ); done += 4;
