@@ -18,7 +18,7 @@
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"appUtilConfig.h"
 
 #   include	<stdlib.h>
 #   include	<string.h>
@@ -34,7 +34,7 @@
 
 static int sioLzwSeek(		void *			voidsos,
 				long			pos )
-    { LDEB(1); return -1; return 0; }
+    { LDEB(1); return -1;	}
 
 /************************************************************************/
 /*									*/
@@ -159,6 +159,13 @@ typedef struct LzwInputStream
 /*									*/
 /*  1)  As long as we need to get more bytes from input stream for	*/
 /*	next code							*/
+/*  2)  Extract the code.						*/
+/*  3)  And shift it away.						*/
+/*  4)  Increment the next code to be implicitly expected. (What the	*/
+/*	encoder is supposed to send next) and if it is beyond what fits	*/
+/*	in the current number of bits increment the number of bits.	*/
+/*	NOTE however that codes above 4095 are used for special		*/
+/*	signaling.							*/
 /*									*/
 /************************************************************************/
 
@@ -198,14 +205,14 @@ static int sioInLzwReadCode(	LzwInputStream *	lis,
 	ls->lsCrntShiftState += 8;
 	}
 
+    /*  2  */
     *pCode = ls->lsCrntShiftDWord & CodeMasks[ls->lsRunningBits];
 
+    /*  3  */
     ls->lsCrntShiftDWord >>= ls->lsRunningBits;
     ls->lsCrntShiftState -=  ls->lsRunningBits;
 
-    /* If code cannt fit into RunningBits bits, must raise its size. Note */
-    /* however that codes above 4095 are used for special signaling.      */
-
+    /*  4  */
     if  ( ++ls->lsRunningCode > ls->lsMaxCode1	&&
 	  ls->lsRunningBits < LZ_BITS		)
 	{
@@ -219,10 +226,10 @@ static int sioInLzwReadCode(	LzwInputStream *	lis,
 /************************************************************************/
 /*									*/
 /*  Routine to trace the Prefixes linked list until we get a prefix	*/
-/*  which is not code, but a pixel value (less than ClearCode).		*/
+/*  which is not a code, but a pixel value (less than ClearCode).	*/
 /*  Returns that pixel value.						*/
-/*  If image is defective, we might loop here forever, so we limit	*/
-/*  the loops to the maximum possible if image O.k. - LZ_MAX_CODE	*/
+/*  If the image is defective, we might loop here forever, so we limit	*/
+/*  the loops to the maximum possible if is image O.k.: LZ_MAX_CODE	*/
 /*  times.								*/
 /*									*/
 /************************************************************************/
@@ -243,12 +250,17 @@ static int sioInLzwGetPrefixChar(	const unsigned int *	Prefix,
 /************************************************************************/
 /*									*/
 /*  The LZ decompression routine:					*/
+/*									*/
 /*  This version decompress the given gif file into Line of length	*/
 /*  LineLen.								*/
 /*  This routine can be called few times (one per scan line, for	*/
 /*  example), in order to complete the whole image.			*/
 /*									*/
-/*  1)  Pop the contents of the stack before reading the input stream.	*/
+/*  1)  To not try to continue after the end of input has been found	*/
+/*	nor after a previous error.					*/
+/*  2)  Pop the contents of the stack before reading the input stream.	*/
+/*  3)  Until a sufficient number of bytes is returned, read codes from	*/
+/*	the input stream and process them.				*/
 /*									*/
 /************************************************************************/
 
@@ -279,16 +291,15 @@ static int sioInLzwReadBytes(	void *		voidlis,
     ClearCode = ls->lsClearCode;
     LastCode= lis->lisLastCode;
 
+    /*  1  */
     if  ( lis->lisExhausted )
 	{ LDEB(lis->lisExhausted); return 0; }
 
-    /*  1  */
-    if  ( StackPtr != 0 )
-	{
-	while( StackPtr != 0 && i < count )
-	    { buffer[i++]= Stack[--StackPtr];	}
-	}
+    /*  2  */
+    while( StackPtr > 0 && i < count )
+	{ buffer[i++]= Stack[--StackPtr];	}
 
+    /*  3  */
     while( i < count )
 	{
 	if  ( sioInLzwReadCode( lis, &CrntCode ) )
@@ -393,21 +404,21 @@ static int sioInLzwReadBytes(	void *		voidlis,
 /*									*/
 /************************************************************************/
 
-static int sioInLzwClose(	void *	voidbis )
+static int sioInLzwClose(	void *	voidfis )
     {
     int				rval= 0;
-    LzwInputStream *		lis= (LzwInputStream *)voidbis;
+    LzwInputStream *		lis= (LzwInputStream *)voidfis;
 
     /*  1 */
     while ( ! lis->lisExhausted )
 	{
 	unsigned char	buffer[SIOsizBUF];
 
-	if  ( sioInLzwReadBytes( voidbis, buffer, SIOsizBUF ) < 0 )
+	if  ( sioInLzwReadBytes( voidfis, buffer, SIOsizBUF ) < 0 )
 	    { LDEB(1); rval= -1; break;	}
 	}
 
-    free( voidbis );
+    free( voidfis );
 
     return rval;
     }
@@ -478,13 +489,6 @@ typedef struct GifHashTableType {
 * evaluating more complex keys (such as twin prime keys) is not worth it!     *
 ******************************************************************************/
 
-# if 0
-static int KeyItem(unsigned long Item)
-{
-    return ((Item >> 12) ^ Item) & HT_KEY_MASK;
-}
-# endif
-
 # define KeyItem(Item) \
     ((((unsigned long)(Item) >> 12) ^ (unsigned long)(Item)) & HT_KEY_MASK)
 
@@ -492,6 +496,7 @@ static int KeyItem(unsigned long Item)
 * Routine to clear the HashTable to an empty state.			      *
 * This part is a little machine depended. Use the commented part otherwise.   *
 ******************************************************************************/
+
 static void _ClearHashTable(GifHashTableType *HashTable)
 {
     memset(HashTable -> HTable, 0xFF, HT_SIZE * sizeof(long));
@@ -501,6 +506,7 @@ static void _ClearHashTable(GifHashTableType *HashTable)
 * Routine to insert a new Item into the HashTable. The data is assumed to be  *
 * new one.								      *
 ******************************************************************************/
+
 static void _InsertHashTable(GifHashTableType *HashTable, unsigned long Key, int Code)
 {
     int HKey = KeyItem(Key);
@@ -516,10 +522,12 @@ static void _InsertHashTable(GifHashTableType *HashTable, unsigned long Key, int
 * Routine to test if given Key exists in HashTable and if so returns its code *
 * Returns the Code if key was found, -1 if not.				      *
 ******************************************************************************/
-static int _ExistsHashTable(GifHashTableType *HashTable, unsigned long Key)
+
+static int _ExistsHashTable(	GifHashTableType *	HashTable,
+				unsigned long		Key )
 {
-    int HKey = KeyItem(Key);
-    unsigned long *HTable = HashTable -> HTable, HTKey;
+    int			HKey= KeyItem(Key);
+    unsigned long *	HTable= HashTable -> HTable, HTKey;
 
     while ((HTKey = HT_GET_KEY(HTable[HKey])) != 0xFFFFFL) {
 	if (Key == HTKey) return HT_GET_CODE(HTable[HKey]);
@@ -548,6 +556,10 @@ typedef struct LzwOutputStream
 /*  This routine is responsible for the compression of the bit stream	*/
 /*  into 8 bits (byte) packets.						*/
 /*									*/
+/*  1)  If code cannot fit into RunningBits bits, must raise its size.	*/
+/*	Note however that codes above 4095 are used for special		*/
+/*	signaling.							*/
+/*									*/
 /************************************************************************/
 
 static int sioOutLzwWriteCode(	LzwOutputStream *	los,
@@ -556,10 +568,10 @@ static int sioOutLzwWriteCode(	LzwOutputStream *	los,
     LzwState *			ls= &(los->losState);
     int				rval= 0;
 
-    ls->lsCrntShiftDWord |= ((long) Code) << ls->lsCrntShiftState;
+    ls->lsCrntShiftDWord |= ( (long)Code ) << ls->lsCrntShiftState;
     ls->lsCrntShiftState += ls->lsRunningBits;
 
-    while (ls->lsCrntShiftState >= 8 )
+    while( ls->lsCrntShiftState >= 8 )
 	{
 	/* Dump out full bytes: */
 	if  ( sioOutPutCharacter( ls->lsCrntShiftDWord & 0xff,
@@ -570,11 +582,10 @@ static int sioOutLzwWriteCode(	LzwOutputStream *	los,
 	ls->lsCrntShiftState -= 8;
 	}
 
-    /* If code cannot fit into RunningBits bits, must raise its size.	  */
-    /* Note however that codes above 4095 are used for special signaling. */
-    if ( ls->lsRunningCode >= ls->lsMaxCode1 && Code <= 4095) {
-       ls->lsMaxCode1 = 1 << ++ls->lsRunningBits;
-    }
+    /*  1  */
+    if  ( ls->lsRunningCode >= ls->lsMaxCode1	&&
+	  Code <= LZ_MAX_CODE			)
+	{ ls->lsMaxCode1= 1 << ++ls->lsRunningBits;	}
 
     return rval;
 }
@@ -639,6 +650,9 @@ static int sioOutLzwClose(	void *		voidlos )
 /*	pixel value.							*/
 /*  6)  BUT.. If the hash table is full, send a Clear code and clear	*/
 /*	the hash table as well.						*/
+/*  7)  Writing is some codes behind as long as there is a code for the	*/
+/*	current string in the hash table. Keep the current code on the	*/
+/*	compressor to be used in the next round.			*/
 /*									*/
 /************************************************************************/
 
@@ -649,7 +663,7 @@ static int sioOutLzwWriteBytes(	void *			voidlos,
     LzwOutputStream *		los= (LzwOutputStream *)voidlos;
     LzwState *			ls= &(los->losState);
 
-    int				CrntCode;
+    int				currentCode;
     int				i= 0;
 
     static unsigned char CodeMask[]=
@@ -667,8 +681,8 @@ static int sioOutLzwWriteBytes(	void *			voidlos,
 
     /*  1  */
     if  ( ls->lsCurrentCode == FIRST_CODE )
-	{ CrntCode= buffer[i++] & CodeMask[ls->lsInitialCodeSize];	}
-    else{ CrntCode= ls->lsCurrentCode;					}
+	{ currentCode= buffer[i++] & CodeMask[ls->lsInitialCodeSize];	}
+    else{ currentCode= ls->lsCurrentCode;				}
 
     while( i < count )
 	{
@@ -677,26 +691,26 @@ static int sioOutLzwWriteBytes(	void *			voidlos,
 	int	NewCode;
 
 	/*  2  */
-	NewKey= (((unsigned long) CrntCode) << 8) + Pixel;
+	NewKey= ( ((unsigned long) currentCode ) << 8) + Pixel;
 
 	/*  3  */
 	NewCode= _ExistsHashTable( &(los->losHashTable), NewKey );
 
 	/*  4  */
 	if  ( NewCode >= 0 )
-	    { CrntCode= NewCode;	}
+	    { currentCode= NewCode;	}
 	else{
 	    /*  5  */
-	    if  ( sioOutLzwWriteCode( los, CrntCode ) )
-		{ LDEB(CrntCode); return -1;	}
+	    if  ( sioOutLzwWriteCode( los, currentCode ) )
+		{ LDEB(currentCode); return -1;	}
 
-	    CrntCode= Pixel;
+	    currentCode= Pixel;
 
 	    /*  6  */
 	    if  ( ls->lsRunningCode >= LZ_MAX_CODE )
 		{
 		if  ( sioOutLzwWriteCode( los, ls->lsClearCode ) )
-		    { LDEB(CrntCode); return -1;	}
+		    { LDEB(currentCode); return -1;	}
 
 		ls->lsRunningCode = ls->lsEOFCode + 1;
 		ls->lsRunningBits = ls->lsInitialCodeSize + 1;
@@ -710,35 +724,57 @@ static int sioOutLzwWriteBytes(	void *			voidlos,
 	   }
 	}
 
-    /* Preserve the current state of the compression algorithm: */
-    ls->lsCurrentCode= CrntCode;
+    /*  7  */
+    ls->lsCurrentCode= currentCode;
 
     return count;
 }
 
+/************************************************************************/
+/*									*/
+/*  Open a 12 bit LZW output stream.					*/
+/*									*/
+/*  NOTE that the initial code size has been communicated outside the	*/
+/*	compressed stream. In the GIF case even before the packeted	*/
+/*	stream packet header of the first packet.			*/
+/*									*/
+/*  1)  Allocate memory and remember the output stream.			*/
+/*  2)  Initialize the hash table by clearing it.			*/
+/*  3)  Initialize the general LZW administration for the current code	*/
+/*	size.								*/
+/*  4)  General SioOut administration.					*/
+/*  Z)  Start with a clear code to be sure that the decoder has also	*/
+/*	cleared its hash table.						*/
+/*									*/
+/************************************************************************/
+
 SimpleOutputStream * sioOutLzwOpen(	SimpleOutputStream *	sosLzw,
 					int			codeSize )
     {
     SimpleOutputStream *	sos;
     LzwOutputStream *		los;
 
+    /*  1  */
     los= (LzwOutputStream *)malloc( sizeof(LzwOutputStream) );
     if  ( ! los )
 	{ XDEB(los); return (SimpleOutputStream *)0;	}
 
     los->losSosLzw= sosLzw;
 
-    /* Clear hash table and send Clear to make sure the decoder do the same. */
+    /*  2  */
     _ClearHashTable( &(los->losHashTable) );
 
+    /*  3  */
     sioLzwInitState( &(los->losState), codeSize );
 
+    /*  4  */
     sos= sioOutOpen( (void *)los, sioOutLzwWriteBytes,
 					    sioLzwSeek, sioOutLzwClose );
 
     if  ( ! sos )
 	{ XDEB(sos); free( los ); return (SimpleOutputStream *)0; }
 
+    /*  Z  */
     if  ( sioOutLzwWriteCode( los, los->losState.lsClearCode ) )
 	{ LDEB(1); sioOutClose( sos ); return (SimpleOutputStream *)0; }
 
