@@ -10,8 +10,11 @@
 #   include	<bmcolor.h>
 
 /************************************************************************/
+/*									*/
 /*  Color encodings.							*/
+/*									*/
 /************************************************************************/
+
 #   define	BMcoBLACKWHITE		0
 #   define	BMcoWHITEBLACK		1
 #   define	BMcoRGB			2
@@ -24,16 +27,22 @@ extern int		bmcoStringToInt( const char * colorEncodingString );
 extern const char *	bmcoStrings[];
 
 /************************************************************************/
+/*									*/
 /*  Units of measurement.						*/
+/*									*/
 /************************************************************************/
-#   define	BMunCM			0
+
+#   define	BMunM			0
 #   define	BMunINCH		1
 #   define	BMunPOINT		2
+#   define	BMunPIXEL		3
 
-#   define	BMunILLEGALVALUE	3
+#   define	BMunILLEGALVALUE	4
 
-#   define	POINTS_PER_CM		28.3465
-#   define	TWIPS_PER_CM		(20*POINTS_PER_CM)
+#   define	x_POINTS_PER_CM		28.3465
+#   define	POINTS_PER_M		2834.65
+#   define	x_TWIPS_PER_CM		(20*POINTS_PER_CM)
+#   define	TWIPS_PER_M		(20*POINTS_PER_M)
 
 extern const char *	bmunIntToString( int unitInt );
 extern int		bmunStringToInt( const char * unitString );
@@ -367,7 +376,7 @@ extern void bmFreeGroups( void **			groups,
 /*  Palette expansion for drawing.					*/
 /************************************************************************/
 
-void bmExpandRGB8Palette(	unsigned char *		to,
+int bmExpandRGB8Palette(	unsigned char *		to,
 				const unsigned char *	from,
 				int			pixelsWide,
 				int			bitsPerColor,
@@ -454,12 +463,21 @@ extern int bmFlipBytes(		unsigned char *	buffer,
 				int		byteCount,
 				int		bitsPerPixel );
 
+int bmMapImageColors(		const BitmapDescription *	bd,
+				const int *			map,
+				unsigned char *			buffer );
+
 extern int bmAverage(		BitmapDescription *		bdOut,
 				const BitmapDescription *	bdIn,
 				unsigned char **		pBufOut,
 				const unsigned char *		bufIn,
 				int				pixels );
 
+extern int bmExpandPaletteImage( BitmapDescription *		bdOut,
+				const BitmapDescription *	bdIn,
+				unsigned char **		pBufOut,
+				const unsigned char *		bufIn );
+
 extern int bmFillImage(		ColorAllocator *		ca,
 				int				bitmapUnit,
 				int				swapBitmapBytes,
@@ -475,4 +493,20 @@ extern int bmTransparentImage(	BitmapDescription *		bdOut,
 				int				wide,
 				int				high );
 
+extern int bmGammaCorrect(	BitmapDescription *		bdOut,
+				const BitmapDescription *	bdIn,
+				unsigned char **		pBufOut,
+				const unsigned char *		bufIn,
+				double				gammaValue );
+
+extern int bmInvertImage(	BitmapDescription *		bdOut,
+				const BitmapDescription *	bdIn,
+				unsigned char **		pBufOut,
+				const unsigned char *		bufIn );
+
+extern void bmImageSizeTwips(
+			int *				pImageWideTwips,
+			int *				pImageHighTwips,
+			const BitmapDescription *	bd );
+
 #   endif
