@@ -1,4 +1,4 @@
-#   include	"config.h"
+#   include	"bitmapConfig.h"
 
 #   include	"bmintern.h"
 #   include	<limits.h>
@@ -6,15 +6,18 @@
 #   include	<appDebugon.h>
 
 /************************************************************************/
+/*									*/
 /*  Expand a palette from one buffer to another one. Do it in such a	*/
 /*  way ( reverse order ) that it works with from == to.		*/
+/*									*/
 /************************************************************************/
+
 #   define	setBytes(t,p,f)	\
     { *(t--)= p[f].rgb8Blue; *(t--)= p[f].rgb8Green; *(t--)= p[f].rgb8Red; }
 #   define	setAlpha(t,p,f)	\
     { *(t--)= (f)?0xff:0x00; }
 
-void bmExpandRGB8Palette(	unsigned char *		to,
+int bmExpandRGB8Palette(	unsigned char *		to,
 				const unsigned char *	from,
 				int			pixelsWide,
 				int			bitsPerPixel,
@@ -24,15 +27,16 @@ void bmExpandRGB8Palette(	unsigned char *		to,
     unsigned char	f1, f2;
 
     if  ( hasAlpha )
-	{ to += ( 32*           pixelsWide - 1 )/8; }
-    else{ to += ( 24*           pixelsWide - 1 )/8; }
-    from +=     ( bitsPerPixel* pixelsWide - 1 )/8;
+	{ to += 4* pixelsWide- 1;	}
+    else{ to += 3* pixelsWide- 1;	}
+
+    from += ( bitsPerPixel* pixelsWide - 1 )/8;
 
     switch( bitsPerPixel )
 	{
 	case	16:
 	    if  ( ! hasAlpha )
-		{ LLDEB(bitsPerPixel,hasAlpha); return; }
+		{ LLDEB(bitsPerPixel,hasAlpha); return -1; }
 
 	    while( pixelsWide > 0 )
 		{
@@ -42,6 +46,7 @@ void bmExpandRGB8Palette(	unsigned char *		to,
 		pixelsWide--;
 		}
 	    break;
+
 	case	8:
 	    if  ( hasAlpha )
 		{
@@ -62,9 +67,10 @@ void bmExpandRGB8Palette(	unsigned char *		to,
 		    }
 		}
 	    break;
+
 	case	4:
 	    if  ( hasAlpha )
-		{ LDEB(hasAlpha); return;	}
+		{ LDEB(hasAlpha); return -1;	}
 	    while( pixelsWide > 0 )
 		{
 		f1= *(from--);
@@ -73,6 +79,7 @@ void bmExpandRGB8Palette(	unsigned char *		to,
 		pixelsWide -= 2;
 		}
 	    break;
+
 	case	2:
 	    if  ( hasAlpha )
 		{
@@ -102,6 +109,7 @@ void bmExpandRGB8Palette(	unsigned char *		to,
 		    }
 		}
 	    break;
+
 	case	1:
 	    while( pixelsWide > 0 )
 		{
@@ -117,11 +125,82 @@ void bmExpandRGB8Palette(	unsigned char *		to,
 		pixelsWide -= 8;
 		}
 	    break;
+
 	default:
-	    LDEB(bitsPerPixel); return;
+	    LDEB(bitsPerPixel); return -1;
 	}
 
-    return;
+    return 0;
+    }
+
+int bmExpandPaletteImage(	BitmapDescription *		bdOut,
+				const BitmapDescription *	bdIn,
+				unsigned char **		pBufOut,
+				const unsigned char *		bufIn )
+    {
+    int				row;
+    const unsigned char *	from;
+    unsigned char *		to;
+
+    BitmapDescription	bd;
+    unsigned char *	buffer;
+
+    switch( bdIn->bdColorEncoding )
+	{
+	case BMcoBLACKWHITE:
+	case BMcoWHITEBLACK:
+	case BMcoRGB:
+	    LDEB(bdIn->bdColorEncoding);
+	    return -1;
+
+	case BMcoRGB8PALETTE:
+	    break;
+	}
+
+    /************************************************************/
+    /*  Derive properties of output bitmap from input.		*/
+    /************************************************************/
+    bmInitDescription( &bd );
+    bmCopyDescription( &bd, bdIn );
+
+    bd.bdColorEncoding= BMcoRGB;
+    bd.bdBitsPerSample= 8;
+    bd.bdSamplesPerPixel= 3;
+    bd.bdBitsPerPixel= 24;
+    bd.bdBytesPerRow= 3* bd.bdPixelsWide;
+    bd.bdBufferLength= bd.bdPixelsHigh* bd.bdBytesPerRow;
+
+    /************************************************************/
+    /*  Allocate new buffer.					*/
+    /************************************************************/
+    buffer= (unsigned char *)malloc( bd.bdBufferLength );
+    if  ( ! buffer )
+	{
+	LLDEB(bd.bdBufferLength,buffer);
+	bmCleanDescription( &bd );
+	return -1;
+	}
+
+    from= bufIn; to= buffer;
+    for ( row= 0; row < bdIn->bdPixelsHigh; row++ )
+	{
+	if  ( bmExpandRGB8Palette( to, from,
+				    bdIn->bdPixelsWide, bdIn->bdBitsPerPixel,
+				    bdIn->bdRGB8Palette, 0 ) )
+	    {
+	    LDEB(1);
+	    bmCleanDescription( &bd ); free( buffer );
+	    return -1;
+	    }
+
+	from += bdIn->bdBytesPerRow;
+	to += bd.bdBytesPerRow;
+	}
+
+    *pBufOut= buffer;
+    *bdOut= bd;
+
+    return 0;
     }
 
 /************************************************************************/
@@ -155,6 +234,7 @@ int bmMakeGrayPalette(		const BitmapDescription *	bd,
 			palette[colorCount- i- 1].rgb8Green=
 			palette[colorCount- i- 1].rgb8Blue=
 					    ( i* 255 )/ ( colorCount- 1 );
+			palette[colorCount- i- 1].rgb8Alpha= 255;
 			}
 
 		    *pColorCount= colorCount; return 0;
@@ -175,6 +255,7 @@ int bmMakeGrayPalette(		const BitmapDescription *	bd,
 			palette[i].rgb8Red=
 			palette[i].rgb8Green=
 			palette[i].rgb8Blue= ( i* 255 )/ ( colorCount- 1 );
+			palette[colorCount- i- 1].rgb8Alpha= 255;
 			}
 
 		    *pColorCount= colorCount; return 0;
@@ -229,6 +310,7 @@ int bmInflateTo8bit(		unsigned char *			to,
 		    *(to++)= ( b & 0x01 )     ;
 		    }
 		}
+
 	    return 0;
 
 	case 2:
@@ -266,6 +348,7 @@ int bmInflateTo8bit(		unsigned char *			to,
 		    *(to++)= ( b & 0x03 )     ;
 		    }
 		}
+
 	    return 0;
 
 	case 4:
@@ -293,6 +376,7 @@ int bmInflateTo8bit(		unsigned char *			to,
 		    *(to++)= ( b & 0x0f )     ;
 		    }
 		}
+
 	    return 0;
 
 	case 8:
@@ -311,6 +395,22 @@ int bmInflateTo8bit(		unsigned char *			to,
 
 	    return 0;
 
+	case 16:
+	    if  ( ! removeAlpha )
+		{ LDEB(removeAlpha); return -1;	}
+
+	    for ( col= 0; col < bd->bdPixelsWide; col += 1 )
+		{
+		b= *(from++);
+
+		if  ( *from == 0 )
+		    { b= transpColor;	}
+
+		*(to++)= b; from++;
+		}
+
+	    return 0;
+
 	default:
 	    LDEB(bd->bdBitsPerPixel); return -1;
 	}
