@@ -1,4 +1,4 @@
-#   include	"config.h"
+#   include	"bitmapConfig.h"
 
 #   include	"bmintern.h"
 #   include	<string.h>
@@ -395,19 +395,19 @@ static void bmDelimitColorBox(		ColorBox *		cb,
     for ( i= 1; i < cb->cbColorCount; he++, i++ )
 	{
 	if  ( cb->cbRMin > he->heRed )
-	    { cb->cbRMin = he->heRed;	}
+	    { cb->cbRMin=  he->heRed;	}
 	if  ( cb->cbRMax < he->heRed )
-	    { cb->cbRMax = he->heRed;	}
+	    { cb->cbRMax=  he->heRed;	}
 
 	if  ( cb->cbGMin > he->heGreen )
-	    { cb->cbGMin = he->heGreen; }
+	    { cb->cbGMin=  he->heGreen; }
 	if  ( cb->cbGMax < he->heGreen )
-	    { cb->cbGMax = he->heGreen; }
+	    { cb->cbGMax=  he->heGreen; }
 
 	if  ( cb->cbBMin > he->heBlue )
-	    { cb->cbBMin = he->heBlue; }
+	    { cb->cbBMin=  he->heBlue; }
 	if  ( cb->cbBMax < he->heBlue )
-	    { cb->cbBMax = he->heBlue; }
+	    { cb->cbBMax=  he->heBlue; }
 	}
 
     return;
