@@ -3,7 +3,7 @@
 /*  errors.							*/
 /****************************************************************/
 
-#   include	"config.h"
+#   include	"indConfig.h"
 
 #   include	<charnames.h>
 
@@ -329,7 +329,7 @@ PossibleWord * indMaximalPossibility(	SpellScanJob *	ssj	)
     if  ( ! rval )
 	{ return rval;	}
 
-    while( rval->pwAcceptedAt >= 0 )
+    while( rval && rval->pwAcceptedAt >= 0 )
 	{ rval= rval->pwNext; }
 
     if  ( ! rval )
